@@ -57,7 +57,7 @@ insert_access_list(
 	int	type)
 {
 ACCESS_LIST * al;
-	al = d_alloc(sizeof(*al),183);
+	al = d_alloc(sizeof(*al));
 	al->ip = ip;
 	al->mask = mask;
 	if ( ip )
