@@ -47,7 +47,7 @@ char * ptr;
 char * ret, * dst;
 
 	ptr = buf;
-	ret = dst = d_alloc(strlen(buf)+2,23);
+	ret = dst = d_alloc(strlen(buf)+2);
 
 	if ( buf[0] == '/' ) {
 		ptr++;
@@ -68,7 +68,7 @@ char * ptr;
 char * ret, * dst;
 
 	ptr = buf;
-	ret = dst = d_alloc(strlen(buf)+2,23);
+	ret = dst = d_alloc(strlen(buf)+2);
 
 	if ( buf[0] == ':' ) {
 		ptr++;
