@@ -20,7 +20,7 @@
 #include <stdio.h>
 #include <errno.h>
 #include	"machine/include.h"
-#include	"utils.h"
+#include	"u_file.h"
 
 int
 u_open(char * filename,int flags,int mode)
@@ -48,8 +48,20 @@ u_read(int fd,void * data,int len)
 }
 
 int
-u_lseek(int fd,int where,int ofs)
+u_lseek(int fd,int ofs,int where)
 {
-	return lseek(fd,where,ofs);
+	return lseek(fd,ofs,where);
+}
+
+int
+u_open64(char * filename,int flags,int mode)
+{
+	return open64(filename,flags,mode);
+}
+
+INTEGER64
+u_lseek64(int fd,INTEGER64 ofs,int where)
+{
+	return lseek64(fd,ofs,where);
 }
 
