@@ -53,5 +53,7 @@ struct rlimit rr;
 	mem_size = rr.rlim_max;
 	if ( mem_size > (256<<20) )
 		mem_size = (256<<20);
+	else if ( mem_size == 0 )
+		mem_size = 1024*1024;
 	return mem_size;
 }
