@@ -42,7 +42,7 @@ struct rlimit r;
 	}
 }
 
-unsigned int
+INTEGER64
 _get_mem_size()
 {
 static unsigned int mem_size;
@@ -51,7 +51,7 @@ int id;
 char buf[100];
 char * ptr;
 int er;
-unsigned int ret;
+INTEGER64 ret;
 struct rlimit rr;
 
 	if ( mem_size )
@@ -84,7 +84,7 @@ struct rlimit rr;
 	else if ( strcmp(ptr,"Gigabytes\n") == 0 )
 		ret *= 1024*1024*1024;
 	getrlimit(RLIMIT_DATA,&rr);
-	if ( ret > (unsigned int)rr.rlim_max )
+	if ( rr.rlim_max && ret > (unsigned int)rr.rlim_max )
 		ret = rr.rlim_max;
 	mem_size = ret;
 	return ret;
