@@ -24,7 +24,6 @@ SEM fork_lock;
 int flock_count;
 FORK_LOCK_TBL * flock_list;
 
-void _wlock_tick();
 
 int tick_func_flag;
 
@@ -79,6 +78,13 @@ FORK_LOCK_TBL * t;
 		wakeup_task((int)&flock_count);
 }
 
+void
+wlock_tick()
+{
+	lock_task(fork_lock);
+	_wlock_tick();
+	unlock_task(fork_lock,"wlock_tick");
+}
 
 void
 _wlock_fork()
@@ -90,7 +96,7 @@ FORK_LOCK_TBL * t;
 		pthread_kill(get_hard_tid(t->tid),SIGUSR1);
 	}
 	if ( tick_func_flag == 0 )
-		new_tick(_wlock_tick,2);
+		new_tick(wlock_tick,2);
 	tick_func_flag = 1;
 	for ( ; flock_list ; ) {
 		wakeup_task((int)&flock_count);
