@@ -17,7 +17,7 @@
 
 #include	<sys/types.h>
 #include	<sys/stat.h>
-#include	"utils.h"
+#include	"u_file.h"
 
 int
 u_stat(char * path,U_STAT * buf)
