@@ -19,6 +19,7 @@
 
 #include	<stdio.h>
 #include	<stdlib.h>
+#include	"machine/gb_windows.h"
 void
 er_panic(char * str)
 {
@@ -27,3 +28,20 @@ er_panic(char * str)
 	exit(1);
 }
 
+void print_win_error()
+{
+	LPVOID lpMsgBuf;
+	FormatMessage(
+		FORMAT_MESSAGE_ALLOCATE_BUFFER |
+		FORMAT_MESSAGE_FROM_SYSTEM |
+		FORMAT_MESSAGE_IGNORE_INSERTS,
+		NULL,
+		GetLastError(),
+		MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
+		(LPTSTR) &lpMsgBuf,
+		0,
+		NULL
+	);
+	printf(lpMsgBuf);
+	LocalFree(lpMsgBuf);
+}
\ No newline at end of file
