@@ -32,8 +32,9 @@
 #include	"memory_debug.h"
 #include	"stream.h"
 #include	"task.h"
+#include	"utils.h"
 #include	<sys/types.h>
-
+#include	"machine/stream.h"
 
 
 extern SEM stream_lock;
@@ -49,14 +50,15 @@ int s_flush_file();
 int s_vscanf_file();
 int s_proc_send_file();
 STREAM * s_proc_recv_file();
-STREAM * s_open_file_descripter();
+STREAM * _s_open_file_descripter();
 
 S_TABLE s_file_table = {
 	'f',
 	0,
 	{0,0},
 	NULL,
-	s_open_file_descripter,
+	/* In windows, we can not get open-mode from descripter, so don't use s_open_file_descripter */
+	_s_open_file_descripter,
 	s_close_file,
 	s_write_file,
 	s_read_file,
@@ -65,6 +67,7 @@ S_TABLE s_file_table = {
 	s_proc_recv_file
 };
 
+/*
 S_FILE __s_std[3] = {
 	{	{	&s_file_table,
 			O_RDONLY
@@ -85,6 +88,30 @@ S_FILE __s_std[3] = {
 		stderr
 	}
 };
+*/
+
+S_FILE __s_std[3] = {
+	{	
+		{	&s_file_table,
+			O_RDONLY
+		},
+		0
+	},
+	{	
+		{	&s_file_table,
+			O_WRONLY
+		},
+		0
+	},
+	{	
+		{	&s_file_table,
+			O_WRONLY
+		},
+		0
+	}
+};
+
+
 
 void
 init_file_stream()
@@ -94,55 +121,63 @@ void insert_s_table(S_TABLE * tbl);
 	__s_std[0].hfile = GetStdHandle(STD_INPUT_HANDLE);
 	__s_std[1].hfile = GetStdHandle(STD_OUTPUT_HANDLE);
 	__s_std[2].hfile = GetStdHandle(STD_ERROR_HANDLE);
-
+	
 	insert_s_table(&s_file_table);
 }
 
+STREAM *_s_open_file_descripter(HANDLE hfile, S_TABLE * tbl){
+	printf("WARNING: stream who can not resolve open mode opened.");
+	return s_open_file_descripter(hfile, O_RDWR, TRUE);	
+}
+
+
 STREAM *
-s_open_file_descripter(HANDLE h, S_TABLE * tbl)
+s_open_file_descripter(HANDLE hfile, int open_mode, BOOL do_lock)
 {
 STREAM * ret;
-int mode;
 void _s_open(STREAM * s,int mode);
 	
-	if ( h == INVALID_HANDLE_VALUE)
+	if ( hfile == INVALID_HANDLE_VALUE)
 		return 0; 
-	mode = O_RDONLY;
+	
 	ret = d_alloc(sizeof(S_FILE));
-	ret->h.tbl = tbl;
+	ret->h.tbl = &s_file_table;
 	ret->h.thread = 0;
-	ret->file.hfile= h;
-
-	lock_task(stream_lock);
-	_s_open(ret,mode);
-
-	unlock_task(stream_lock,"s_open_descripter");
+	ret->file.hfile= hfile;
+	
+	if(do_lock)
+		lock_task(stream_lock);
+	_s_open(ret,open_mode);
+	if(do_lock)
+		unlock_task(stream_lock,"s_open_file_descripter");
 	return ret;
 }
 
+/*
 STREAM *
-_s_open_file_descripter(HANDLE h, S_TABLE * tbl)
+_s_open_file_descripter(HANDLE hfile, S_TABLE * tbl)
 {
 STREAM * ret;
 int mode;
-	if ( h == INVALID_HANDLE_VALUE )
+	if ( hfile == INVALID_HANDLE_VALUE )
 		return 0; 
-/*	mode = fcntl(d,F_GETFL);
+	mode = fcntl(d,F_GETFL);
 	if ( mode < 0 )
 		return 0;
 	mode &= ~3;
 	fcntl(d,F_SETFL,mode);
-*/
+
 	mode = O_RDWR;
 	
 	ret = d_alloc(sizeof(S_FILE));
 	ret->h.tbl = tbl;
 	ret->h.thread = 0;
-	ret->file.hfile = h;
+	ret->file.hfile = hfile;
 	
 	_s_open(ret,mode);
 	return ret;
 }
+*/
 
 
 STREAM *
@@ -172,6 +207,9 @@ char * _f;
 	}
 	_f = change_delim_str(filename);
 	ret->file.h.mode = mode;
+	if(strcmp(_f, "&")==0){
+		er_panic("invalid filename");
+	}
 	ret->file.hfile = CreateFile(_f, 
 					access_mode, 
 					FILE_SHARE_READ, 0, 
@@ -205,8 +243,9 @@ s_write_file(STREAM * s,void * data,int len)
 DWORD wrote=0;
 	if(s->file.hfile != INVALID_HANDLE_VALUE)
 		WriteFile(s->file.hfile, data, len, &wrote, NULL );
-	else
+/*	else
 		wrote = fwrite(data, 1, len, s->file.std_fd);
+*/
 	s->h.last_size = len;
 	s->h.last_err = GetLastError();
 	return (int)wrote;
@@ -218,19 +257,19 @@ s_read_file(STREAM * s,void * data,int len)
 DWORD read=0;
 	if(s->file.hfile != INVALID_HANDLE_VALUE)
 		ReadFile(s->file.hfile, data, len, &read, NULL);
-	else
+/*	else
 		read = fread(data, 1, len, s->file.std_fd);
-	return (int)read;
+*/	return (int)read;
 }
 
 int
 s_flush_file(STREAM * s)
 {
-	if(s->file.hfile != INVALID_HANDLE_VALUE)
-		FlushFileBuffers(s->file.hfile);
-	else
+//	if(s->file.hfile != INVALID_HANDLE_VALUE)
+	FlushFileBuffers(s->file.hfile);
+/*	else
 		fflush(s->file.std_fd);
-	return 0;
+*/	return 0;
 }
 
 
@@ -254,32 +293,41 @@ DWORD origin;
 
 
 int
-s_proc_send_file(STREAM * s,PROC_SEND * ps)
+s_proc_send_file(STREAM * s, PROC_SEND_CHUNK** chunk, BOOL close_flag)
 {
-void er_panic(char * str);
+	int flags;
+	
+	PROC_SEND_FILE *ps = (PROC_SEND_FILE *)d_alloc(sizeof(PROC_SEND_FILE));
 
-	int duped_hfile;
-	ps->msg[0] = s->h.tbl->type;
-	ps->msg[1] = 0;
+	ps->header.size = sizeof(PROC_SEND_FILE);
+	ps->header.type = s->h.tbl->type;
+	ps->open_mode = s->h.mode;
+	
+	flags = DUPLICATE_SAME_ACCESS;
+	if(close_flag)
+		flags |= DUPLICATE_CLOSE_SOURCE;
+	
 	if(!DuplicateHandle(
-			GetCurrentProcess(), 
-			s->file.hfile,
-			GetCurrentProcess(),
-			(HANDLE*)&duped_hfile, 0, TRUE, DUPLICATE_SAME_ACCESS)){
-			er_panic("dup error");
+		GetCurrentProcess(), 
+		s->file.hfile, 
+		GetCurrentProcess(), 
+		&ps->hfile,
+		0,
+		TRUE,
+		flags)){
+		er_panic("dup_handler error");
 	}
-	ps->fid[0] = duped_hfile;
-	ps->fid[1] = -1;
+	
+	*chunk = (PROC_SEND_CHUNK*)ps;
+	
 	return 0;
 }
 
 
 STREAM *
-s_proc_recv_file(PROC_RECV * ps)
+s_proc_recv_file(S_TABLE *table, PROC_SEND_CHUNK* chunk)
 {
-HANDLE hfile;
-	ps->ptr++;
-	hfile = (void*)(ps->fidp++);
-	return _s_open_file_descripter(hfile, ps->tbl);
+	PROC_SEND_FILE *ps = (PROC_SEND_FILE *)chunk;
+	return s_open_file_descripter(ps->hfile, ps->open_mode, FALSE);
 }
 
