@@ -33,6 +33,8 @@
 #include	<sys/types.h>
 #include	<io.h>
 #include	"flush_pipe.h"
+#include	"machine/stream.h"
+
 
 extern STREAM * stream_list;
 extern SEM stream_lock;
@@ -56,8 +58,8 @@ S_TABLE s_fpipe_table = {
 	s_write_fpipe,
 	s_read_fpipe,
 	s_flush_fpipe,
-	s_proc_send_fpipe,
-	s_proc_recv_fpipe,
+	0,
+	0,
 	s_get_socketip_fpipe
 };
 
@@ -154,8 +156,6 @@ int
 s_write_fpipe(STREAM * s,void * data,int len)
 {
 int ret;
-char * ptr;
-int _len;
 	if ( len == 0 )
 		return 0;
 
@@ -355,6 +355,73 @@ int ret;
 	return 0;
 }
 
+
+int
+s_proc_send_fpipe(STREAM * s, PROC_SEND_CHUNK** chunk, BOOL close_flag)
+{
+	int flags;
+	PROC_SEND_FPIPE *ps;
+	printf("s_proc_send_fpipe called!\n");
+
+	ps = (PROC_SEND_FPIPE *)d_alloc(sizeof(PROC_SEND_FPIPE));
+
+	ps->header.size = sizeof(PROC_SEND_FILE);
+	ps->header.type = s->h.tbl->type;
+	ps->open_mode = s->h.mode;
+	
+	flags = DUPLICATE_SAME_ACCESS;
+	if(close_flag)
+		flags |= DUPLICATE_CLOSE_SOURCE;
+	
+	if(!DuplicateHandle(
+		GetCurrentProcess(), 
+		(HANDLE)s->fpipe.fid_read, 
+		GetCurrentProcess(), 
+		(LPHANDLE)&ps->fid_read,
+		0,
+		TRUE,
+		flags)){
+		er_panic("dup_handler error");
+	}
+	
+	if(!DuplicateHandle(
+		GetCurrentProcess(), 
+		(HANDLE)s->fpipe.fid_write, 
+		GetCurrentProcess(), 
+		(LPHANDLE)&ps->fid_write,
+		0,
+		TRUE,
+		flags)){
+		er_panic("dup_handler error");
+	}
+	
+	*chunk = (PROC_SEND_CHUNK*)ps;
+	
+	return 0;
+}
+
+
+STREAM *
+s_proc_recv_fpipe(S_TABLE *table, PROC_SEND_CHUNK* chunk)
+{
+STREAM * ret;
+PROC_SEND_FPIPE *ps;
+
+	printf("s_proc_recv_fpipe called!\n");
+	ps = (PROC_SEND_FPIPE *)chunk;
+	ret = d_alloc(sizeof(S_FPIPE));
+	ret->h.tbl = table;
+	ret->h.thread = 0;
+	ret->fpipe.head = ret->fpipe.tail = 0;
+	ret->fpipe.read_flag = 0;
+	ret->fpipe.fid_read = ps->fid_read;
+	ret->fpipe.fid_write = ps->fid_write;
+	_s_open(ret,ps->open_mode);
+	return ret;
+}
+
+
+/*
 int
 s_proc_send_fpipe(STREAM * s,PROC_SEND * ps)
 {
@@ -387,35 +454,15 @@ int mode;
 	ret->fpipe.read_flag = 0;
 
 	fid = pr->fidp ++;
-/* 
-	// winapi dose not have fctrl.
-	mode = fcntl(fid,F_GETFL);
-	if ( mode < 0 ) {
-		d_f_ree(ret);
-		return 0;
-	}
-	mode &= ~3;
-	fcntl(fid,F_SETFL,mode);
-*/
 	ret->fpipe.fid_read = fid;
 
 	fid = pr->fidp ++;
-/*
-	// winapi dose not have fctrl.
-	mode = fcntl(fid,F_GETFL);
-	if ( mode < 0 ) {
-		d_f_ree(ret);
-		return 0;
-	}
-	mode &= ~3;
-	fcntl(fid,F_SETFL,mode);
-*/
 	ret->fpipe.fid_write = fid;
 
 	_s_open(ret,mode);
 	return ret;
 }
-
+*/
 int
 _s_get_fpipe_data_size(STREAM * s)
 {
