@@ -141,3 +141,11 @@ s_set_prompt(STREAM * s,int (*prompt)())
 	s->terminal.prompt = prompt;
 	return 0;
 }
+
+void
+init_terminal_stream()
+{
+extern void insert_s_table(S_TABLE * tbl);
+
+	insert_s_table(&s_socket_table);
+}
\ No newline at end of file
