@@ -49,7 +49,7 @@ char * ptr;
 char * ret, * dst;
 	
 	ptr = buf;
-	ret = dst = d_alloc(len+1,23);
+	ret = dst = d_alloc(len+1);
 
 	if ( buf[0] == '/' ) {
 		ptr++;
@@ -66,7 +66,7 @@ normalize_delim_str(char * buf)
 char * ptr;
 char * ret, * dst;
 	
-	ret = dst = d_alloc(strlen(buf)+2,23);
+	ret = dst = d_alloc(strlen(buf)+2);
 
 	for ( ptr = buf ; *ptr && *ptr != '\\' ; ptr++ ) {
 		if ( *ptr == ':' ) {
