@@ -44,6 +44,18 @@ typedef struct v_set_image_s{
 	int h;
 }V_SET_IMAGE_S;
 
+extern int loop_task_id;
+
+void updateDib(VIMAGE *img){
+	if(img->buf_32){
+		memcpy(img->dib_buffer, img->buf_32, img->w*img->h*4);
+	}else if(img->buf_16){
+		memcpy(img->dib_buffer, img->buf_16, (((img->w+1)/2)*2)*img->h*2);
+	}else{
+		memcpy(img->dib_buffer, img->buf_8, (((img->w+3)/4)*4)*img->h);
+	}
+}
+
 int _v_set_image(V_SET_IMAGE_S *v)
 {
 VERROR * err = v->err;
@@ -59,14 +71,12 @@ short * buf_16;
 char * buf_8;
 int i,j,minh;
 int pixelbits;
-char * dib;
 
 HBITMAP hbm;
 BITMAPINFO info;
-HDC hdc;
 
 	pixelbits = obj->header.win->d->gb2m_map.pixel_bits;
-
+	
 	if ( h != obj->vimage.h || w != obj->vimage.w )
 		obj->vimage.select_flag = 0;
 	size1 = obj->vimage.w*obj->vimage.h;
@@ -150,16 +160,7 @@ HDC hdc;
 	obj->vimage.x = x;
 	obj->vimage.y = y;
 	obj->vimage.w_border = w;
-
-/*
-	obj->vimage.ximage->width = w;
-	obj->vimage.ximage->height = h;
-	obj->vimage.ximage->xoffset = 0;
 	
-	obj->vimage.ximage->bytes_per_line = w*sizeof(long);
-	err->err1 = E_OK;
-*/
-	if (obj->vimage.ximage!=NULL) DeleteObject(obj->vimage.ximage);
 	info.bmiHeader.biSize = sizeof(BITMAPINFOHEADER);
 	info.bmiHeader.biPlanes = 1;
 	info.bmiHeader.biBitCount = pixelbits;
@@ -172,191 +173,14 @@ HDC hdc;
 	info.bmiHeader.biWidth = w;
 	info.bmiHeader.biHeight = -h;
 	
-	hdc = GetDC(obj->vimage._h.win->w);
-	hbm = CreateDIBSection( hdc,&info,DIB_RGB_COLORS, &(obj->vimage.dib_buffer), NULL, 0);
-	
-	dib=obj->vimage.dib_buffer;
-	if (dib)
-	{
-		switch(pixelbits){
-		case 8:
-			{
-				char *buf=obj->vimage.buf_8;
-				int bpl=w; bpl=(bpl+3)/4*4;
-				for(y=0;y<h;y++)
-				{
-					int x=0;
-					char *dest=dib+bpl*y;
-					char *src=buf+w*y;
-					for(x=0;x<w;x++)
-					{
-						*dest++ = *src++;
-					}
-				}
-			}
-			break;
-		case 16:
-			{
-				short *buf=obj->vimage.buf_16;
-				int bpl=2*w; bpl=(bpl+3)/4*4;
-				for(y=0;y<h;y++)
-				{
-					int x=0;
-					short *dest=(short*)(dib+bpl*y);
-					short *src= (buf+w*y);
-					for(x=0;x<w;x++)
-					{
-/*						*dest = 
-							(((*src) & 0x1f) << 10) |
-							(((*src >> 5) & 0x1f) << 5) |
-							((*src >> 10) & 0x1f)  ;
-*/
-						*dest = 
-							(((*src >> 1) & 0x1f)) << 11 |
-							(((*src >> 6) & 0x1f) << 6) |
-							(((*src >> 11) & 0x1f) << 1) ;
-
-//						*dest++ = *src++;
-
-						dest++;src++;
-					}
-				}
-			}
-			break;
-		case 32:
-			{
-				long *buf=obj->vimage.buf_32;
-				int bpl=4*w;
-				for(y=0;y<h;y++)
-				{
-					int x=0;
-					char *dest=(char *)dib+bpl*y;
-					long *src=buf+w*y;
-					// memcpy(dib+bpl*y, (char*)(buf+w*y), w*4);
-					for(x=0;x<w;x++)
-					{
-						long l=*src++;
-						dest[0]=(char)(l>>16);
-						dest[1]=(char)((l>>8)&0xff);
-						dest[2]=(char)(l&0xff);
-						dest+=4;
-					}
-				}
-			}
-
-		}
-	}
-
-	if (obj->vimage.ximage!=NULL) DeleteObject(obj->vimage.ximage);
+	hbm = CreateDIBSection(ghBufferDC, &info, DIB_RGB_COLORS, &(obj->vimage.dib_buffer), NULL, 0);
+	if (obj->vimage.ximage!=NULL) 
+		DeleteObject(obj->vimage.ximage);
 	obj->vimage.ximage = hbm;
-	ReleaseDC(obj->vimage._h.win->w,hdc);
+	updateDib(&obj->vimage);
 	err->err1 = E_OK;
 	return 0;
 }
-/*
-void _v_set_image(V_SET_IMAGE_S *v)
-{
-VERROR * err = v->err;
-VIMAGE * vimage = v->vimage;
-int x = v->x;
-int y = v->y;
-int w = v->w;
-int h = v->h;
-
-int size1,size2;
-long * buf1, *buf2;
-long *buf;
-int i,j;
-int minh,minw;
-HBITMAP hbm;
-BITMAPINFO info;
-HDC hdc;
-HWND hwnd;
-
-char * dib;
-		
-	if ( h != vimage->h || w != vimage->w )
-		vimage->select_flag = 0;
-	
-	size1 = vimage->w*vimage->h;
-	size2 = w*h;
-		
-	minh = h < vimage->h ? h : vimage->h;
-	minw = w < vimage->w ? w : vimage->w;
-
-	if ( size1 < size2 ){
-		buf = d_re_alloc(vimage->buf,size2*sizeof(long));
-	}
-	else{
-		buf = vimage->buf;
-	}
-	if ( w < vimage->w ) {
-		for ( i = 1 ; i < minh ; i ++ ){
-			for ( j = 0 ; j < w ; j ++ ){
-				buf[i*w+j] = buf[i*vimage->w+j];
-			}
-		}
-	}
-	else if ( w > vimage->w ) {
-		for ( i = minh-1 ; i >= 0 ; i -- ){
-			for ( j = vimage->w-1; j >= 0; j -- ){
-				buf[i*w+j] = buf[i*vimage->w+j];
-			}
-		}
-	}
-
-	vimage->buf = buf;
-
-	vimage->w = w;
-	vimage->h = h;
-	vimage->x = x;
-	vimage->y = y;
-	
-	if (vimage->ximage!=NULL) DeleteObject(vimage->ximage);
-	info.bmiHeader.biSize = sizeof(BITMAPINFOHEADER);
-	info.bmiHeader.biPlanes = 1;
-	info.bmiHeader.biBitCount = 24;
-	info.bmiHeader.biCompression = BI_RGB;
-	info.bmiHeader.biSizeImage = 0;
-	info.bmiHeader.biXPelsPerMeter = 0;
-	info.bmiHeader.biYPelsPerMeter = 0;
-	info.bmiHeader.biClrUsed = 0;
-	info.bmiHeader.biClrImportant = 0;
-	info.bmiHeader.biWidth = w;
-	info.bmiHeader.biHeight = -h;
-	
-	hdc = GetDC(vimage->_h.win->w);
-	hbm = CreateDIBSection( hdc,&info,DIB_RGB_COLORS, &(vimage->dib_buffer), NULL, 0);
-	
-	dib=vimage->dib_buffer;
-	if (dib)
-	{
-		long *buf=vimage->buf;
-		int bpl=3*w; bpl=(bpl+3)/4*4;
-		for(y=0;y<h;y++)
-		{
-			int x=0;
-			char *dest=dib+bpl*y;
-			long *src=buf+w*y;
-			for(x=0;x<w;x++)
-			{
-				long l=*src++;
-				dest[0]=(l>>16);
-				dest[1]=(l>>8)&0xff;
-				dest[2]=l&0xff;
-				dest+=3;
-			}
-		}
-	}
-
-	if (vimage->ximage!=NULL) DeleteObject(vimage->ximage);
-	vimage->ximage = hbm;
-	ReleaseDC(vimage->_h.win->w,hdc);
-	err->err1 = E_OK;
-
-}
-
-*/
 
 void v_set_image(VERROR * err,VOBJECT * obj,int x,int y,int w,int h)
 {
@@ -370,60 +194,47 @@ void v_set_image(VERROR * err,VOBJECT * obj,int x,int y,int w,int h)
 	ms_do (_v_set_image, &v, "v_set_image");
 }
 
+int wait_window_update(){
+extern int window_update_flag;
+	window_update_flag = 1;
+	sleep_task(&window_update_flag,0);
+}
+
 int
 _v_redraw_image(void * arg)
 {
 	VIMAGE * vi;
-	char *dib;
-	HDC hdc;
 	HDC memDC;
 	BOOL bPaint=TRUE;
 	HBITMAP obmp;
-	VOBJECT *obj;
+	RECT update_rect;
 
-	int x;
-	int y;
-	int w;
-	int h;
+	vi = &(((VOBJECT *)arg)->vimage);
 
-	obj = (VOBJECT *)arg;
-	vi = &(obj->vimage);
+	updateDib(vi);
 	
-	dib=vi->dib_buffer;
+	memDC = CreateCompatibleDC(ghBufferDC);
+	obmp = SelectObject(memDC, vi->ximage);
+	BitBlt(ghBufferDC, vi->x, vi->x, vi->w, vi->h, memDC, 0, 0, SRCCOPY);
+	SelectObject(memDC,obmp);
+	DeleteDC(memDC);
+
+	update_rect.left = vi->x;
+	update_rect.top = vi->y;
+	update_rect.right = vi->x + vi->w;
+	update_rect.bottom = vi->y + vi->h;
+	InvalidateRect(vi->_h.win->w, &update_rect, FALSE);
+
+	if(get_tid() == loop_task_id)
+		UpdateWindow(vi->_h.win->w);
+	else
+		wait_window_update();
 	
-	x=vi->x;
-	y=vi->y;
-	w=vi->w;
-	h=vi->h;
-
-	if (dib)
-	{
-		VERROR err;
-
-		V_SET_IMAGE_S v;
-		v.err = &err;
-		v.obj = obj;
-		v.w = vi->w;
-		v.h = vi->h;
-		v.x = x;
-		v.y = y;
-
-		_v_set_image(&v);
-
-		hdc = GetDC(vi->_h.win->w);
-		memDC = CreateCompatibleDC(hdc);
-		obmp = SelectObject(memDC,vi->ximage);
-		
-		BitBlt(ghBufferDC,0,0,w,h,memDC,0,0,SRCCOPY);
-		BitBlt(hdc,0,0,w,h,ghBufferDC,0,0,SRCCOPY);
-		ReleaseDC(vi->_h.win->w,hdc);
-
-		SelectObject(memDC,obmp);
-		DeleteObject(memDC);
-	}
 	return 0;
 }
 
+
+
 void v_redraw_image(VOBJECT *obj){
 	ms_do(_v_redraw_image, (void *)obj, "v_redraw");	
 }
@@ -454,8 +265,6 @@ typedef struct v_create_image_s {
 
 int _v_create_image(V_CREATE_IMAGE_S *v)
 {
-//VOBJECT *v_create_image(VERROR * err,VWINDOW *win,int x,int y,int w,int h)
-//{
 HBITMAP		hbm;
 BITMAPINFO	info;
 VOBJECT *	obj;
@@ -466,6 +275,9 @@ int			w;
 int			h;
 HDC			hdc;
 int			buf_alloc_size;
+int			pixel_bits;
+int			border;
+
 
 	win = v->win;
 	x = v->x;
@@ -473,12 +285,13 @@ int			buf_alloc_size;
 	w = v->w;
 	h = v->h;
 
+	pixel_bits = win->d->gb2m_map.pixel_bits;
 	obj = d_alloc(sizeof(VIMAGE));
 	memset(obj, 0, sizeof(VIMAGE));
 	obj->vimage.ximage=NULL;
 	info.bmiHeader.biSize = sizeof(BITMAPINFOHEADER);
 	info.bmiHeader.biPlanes = 1;
-	info.bmiHeader.biBitCount = win->d->gb2m_map.pixel_bits;
+	info.bmiHeader.biBitCount = pixel_bits;
 	info.bmiHeader.biCompression = BI_RGB;
 	info.bmiHeader.biSizeImage = 0;
 	info.bmiHeader.biXPelsPerMeter = 0;
@@ -489,41 +302,49 @@ int			buf_alloc_size;
 	info.bmiHeader.biHeight = -h;
 	hdc = GetDC(win->w);
 	hbm = CreateDIBSection( hdc,&info,DIB_RGB_COLORS, &(obj->vimage.dib_buffer), NULL, 0);
+
+	/*
+	Cannt use vimage.buf_32 direct. buf_32 is d_f_reed at interface.c
+	hbm = CreateDIBSection(hdc, &info, DIB_RGB_COLORS, &(obj->vimage.buf_32), NULL, 0);
+	*/
+
 	ReleaseDC(v->win->w,hdc);
 	
-	buf_alloc_size = (win->d->gb2m_map.pixel_bits/8)*w*h;
-	switch(win->d->gb2m_map.pixel_bits){
+	switch(pixel_bits){
 	case 32:
+		border = w;
+		buf_alloc_size = border*h*4;
 		obj->vimage.buf_32 = (long*)d_alloc(buf_alloc_size);
 		memset(obj->vimage.buf_32, 0, buf_alloc_size);
 		break;
 	case 16:
+		border = ((w+1)/2)*2;
+		buf_alloc_size = border*h*2;
 		obj->vimage.buf_16 = (short*)d_alloc(buf_alloc_size);
 		memset(obj->vimage.buf_16, 0, buf_alloc_size);
 		break;
 	case 8:
+		border = ((w+3)/4)*4;
+		buf_alloc_size = border*h;		
 		obj->vimage.buf_8 = (char*)d_alloc(buf_alloc_size);
 		memset(obj->vimage.buf_8, 0, buf_alloc_size);
 		break;
 	}
 	
-
 	obj->vimage.select_flag = 0;
 	obj->vimage.ximage = hbm;
 	obj->vimage.w = w;
 	obj->vimage.h = h;
 	obj->vimage.x = x;
 	obj->vimage.y = y;
-	obj->vimage.w_border = w;
+	obj->vimage.w_border = border;
 	obj->header.type = VT_IMAGE;
 	obj->header.handler = v_image_handler;
 	obj->header.win = win;
 	obj->header.next = win->obj_list;
-	obj->header.win->gc=NULL;
 	v->win->obj_list = obj;
 	v->err->err1 = E_OK;
 
-//unlock_task(env.wf_lock,"v_create_image");
 	return (int)obj;
 }
 
@@ -539,103 +360,6 @@ VOBJECT *v_create_image(VERROR * err,VWINDOW *win,int x,int y,int w,int h)
 	return (VOBJECT *)ms_do(_v_create_image,(void*)&v, "v_create_image");
 }
 
-/*
-typedef struct v_set_image_s
-{
-	VERROR * err,VOBJECT * obj,int x,int y,int w,int h
-}V_SET_IMAGE_S;
-*/
-/*
-void v_set_image(VERROR * err,VOBJECT * obj,int x,int y,int w,int h)
-{
-int size1,size2;
-long * buf;
-int i,j,minh;
-HBITMAP hbm;
-BITMAPINFO info;
-HDC hdc;
-HWND hwnd;
-
-char * dib;
-
-//lock_task(env.wf_lock);
-
-	if ( h != obj->vimage.h || w != obj->vimage.w )
-		obj->vimage.select_flag = 0;
-
-	size1 = obj->vimage.w*obj->vimage.h;
-	size2 = w*h;
-	minh = h < obj->vimage.h ? h : obj->vimage.h;
-	if ( size1 < size2 )
-		buf = d_re_alloc(obj->vimage.buf,size2*sizeof(long));
-	else	buf = obj->vimage.buf;
-	if ( w < obj->vimage.w ) {
-		for ( i = 1 ; i < minh ; i ++ )
-			for ( j = 0 ; j < w ; j ++ )
-				buf[i*w+j] = buf[i*obj->vimage.w+j];
-	}
-	else if ( w > obj->vimage.w ) {
-		for ( i = minh-1 ; i >= 0 ; i -- )
-			for ( j = obj->vimage.w-1;
-					j >= 0;
-					j -- )
-				buf[i*w+j] = buf[i*obj->vimage.w+j];
-	}
-	if ( size1 > size2 )
-		buf = d_re_alloc(buf,size2*sizeof(long));
-
-	obj->vimage.buf = buf;
-	obj->vimage.w = w;
-	obj->vimage.h = h;
-	obj->vimage.x = x;
-	obj->vimage.y = y;
-
-	if (obj->vimage.ximage!=NULL) DeleteObject(obj->vimage.ximage);
-	info.bmiHeader.biSize = sizeof(BITMAPINFOHEADER);
-	info.bmiHeader.biPlanes = 1;
-	info.bmiHeader.biBitCount = 24;
-	info.bmiHeader.biCompression = BI_RGB;
-	info.bmiHeader.biSizeImage = 0;
-	info.bmiHeader.biXPelsPerMeter = 0;
-	info.bmiHeader.biYPelsPerMeter = 0;
-	info.bmiHeader.biClrUsed = 0;
-	info.bmiHeader.biClrImportant = 0;
-	info.bmiHeader.biWidth = w;
-	info.bmiHeader.biHeight = -h;
-	hwnd=obj->header.win->w;
-	hdc = GetDC(hwnd);
-	hbm = CreateDIBSection( hdc,&info,DIB_RGB_COLORS, &(obj->vimage.dib_buffer), NULL, 0);
-
-	dib=obj->vimage.dib_buffer;
-	if (dib)
-	{
-		long *buf=obj->vimage.buf;
-		int bpl=3*w; bpl=(bpl+3)/4*4;
-		for(y=0;y<h;y++)
-		{
-			int x=0;
-			char *dest=dib+bpl*y;
-			long *src=buf+w*y;
-			for(x=0;x<w;x++)
-			{
-				long l=*src++;
-				dest[0]=(l>>16);
-				dest[1]=(l>>8)&0xff;
-				dest[2]=l&0xff;
-				dest+=3;
-			}
-		}
-	}
-
-	if (obj->vimage.ximage!=NULL) DeleteObject(obj->vimage.ximage);
-	obj->vimage.ximage = hbm;
-	ReleaseDC(hwnd,hdc);
-
-	err->err1 = E_OK;
-
-//unlock_task(env.wf_lock,"v_set_image");
-}
-*/
 int
 v_image_minrect(VRECT * r,VOBJECT * obj)
 {
@@ -768,7 +492,6 @@ V_SELECT_BOX_S v;
 	v.select[0] = st;
 	v.select[1] = end;
 	v.select_flag = flag;
-//	_v_select_box(&v);
 	ms_do(_v_select_box, &v, "v_select_box");
 
 	return 0;
@@ -791,55 +514,30 @@ _v_part_redraw_image(V_PART_REDRAW_IMAGE_S *v)
 	int w = v->w;
 	int h = v->h;
 	
-	char *dib=obj->vimage.dib_buffer;
-	HDC hdc=obj->vimage._h.win->gc;
 	HDC memDC;
 	BOOL bPaint=TRUE;
 	HBITMAP obmp;
-	VERROR err;
-	hdc = GetDC(obj->vimage._h.win->w);
-	/*
-	if (hdc == NULL)
+	
+	updateDib(&obj->vimage);
+	
+	memDC = CreateCompatibleDC(ghBufferDC);
+	obmp = SelectObject(memDC, obj->vimage.ximage);
+	x = x + obj->vimage.x;
+	y = y + obj->vimage.y;
+	BitBlt(ghBufferDC,x,y,w,h,memDC,x,y,SRCCOPY);
+	SelectObject(memDC,obmp);
+	DeleteDC(memDC);
+/*
 	{
-		bPaint = FALSE;
-		hdc = GetDC(obj->vimage._h.win->w);
+		HDC dc = GetDC(0);
+		BitBlt(dc,x,y,w,h,memDC,x,y,SRCCOPY);
+		ReleaseDC(0, dc);
 	}
-	else{
-		er_panic("hdc");
-	}
-	*/
-	if (dib)
-	{
-		int x=obj->vimage.x;
-		int y=obj->vimage.y;
-		int w=obj->vimage.w;
-		int h=obj->vimage.h;
-		V_SET_IMAGE_S v;
-		v.err = &err;
-		v.obj = obj;
-		v.w = w;
-		v.h = h;
-		v.x = x;
-		v.y = y;
-		_v_set_image(&v);
-		//_v_set_image(&err,obj->vimage,x,y,w,h);
-		memDC = CreateCompatibleDC(hdc);
-		obmp = SelectObject(memDC,obj->vimage.ximage);
-
-		BitBlt(ghBufferDC,x,y,w,h,memDC,x,y,SRCCOPY);
-		BitBlt(hdc,x,y,w,h,ghBufferDC,x,y,SRCCOPY);
-
-		//PostThreadMessage(gdwThreadID, MYMSG_INVRECT,0, 0);
-
-		SelectObject(memDC,obmp);
-		DeleteObject(memDC);
-	}
-/*	if (bPaint==FALSE)
-	{
-		ReleaseDC(obj->vimage._h.win->w,hdc);
-	}	
 */
-	ReleaseDC(obj->vimage._h.win->w,hdc);
+	{
+		RECT r = {x, y, x+w, y+h };
+		InvalidateRect(obj->vimage._h.win->w, &r, FALSE);
+	}
 	return 0;
 }
 
@@ -966,14 +664,14 @@ V_GN * v;
 		v->buf = v->obj->vimage.buf_16;
 		v->element_size = sizeof(short);
 		v->obj->vimage.buf_16 = d_alloc(sizeof(short)*
-				v->obj->vimage.w*
+				((v->obj->vimage.w+1)/2)*2*
 				v->obj->vimage.h);
 	}
 	else if ( v->obj->vimage.buf_8 ) {
 		v->buf = v->obj->vimage.buf_8;
 		v->element_size = sizeof(char);
 		v->obj->vimage.buf_8 = d_alloc(sizeof(char)*
-				v->obj->vimage.w*
+				((v->obj->vimage.w+3)/4)*4*
 				v->obj->vimage.h);
 	}
 	else {
