@@ -35,7 +35,7 @@
 
 int motion_cnt;
 
-extern GBVIEW_ENV env;
+VDISPLAY * env_display;
 
 
 SEM interface_lock,opac_lock,interface_redraw_lock;
@@ -178,7 +178,7 @@ int
 ptr_param_func(VPOINT ** ptr)
 {
 VPOINT * ret;
-	ret = d_alloc(sizeof(*ret),125);
+	ret = d_alloc(sizeof(*ret));
 	ret->x = cflame.press_x;
 	ret->y = cflame.press_y;
 	*ptr = ret;
@@ -200,7 +200,7 @@ real_param_func(REAL1 ** ptr)
 {
 REAL1 * ret;
 
-	ret = d_alloc(sizeof(REAL1),135);
+	ret = d_alloc(sizeof(REAL1));
 	*ret = cflame.press_zoom;
 	*ptr = ret;
 	return 0;
@@ -565,14 +565,14 @@ _set_index(int type,int w,int h)
 	switch ( type ) {
 	case PIT_XY:
 		cflame.ix.xy.index_x =
-			d_alloc(sizeof(int)*w,1235);
+			d_alloc(sizeof(int)*w);
 		cflame.ix.xy.index_y =
-			d_alloc(sizeof(int)*h,125);
+			d_alloc(sizeof(int)*h);
 		cflame.ix.type = PIT_XY;
 		break;
 	case PIT_PLANE:
 		cflame.ix.p.index =
-			d_alloc(sizeof(VPOINT)*w*h,1235);
+			d_alloc(sizeof(VPOINT)*w*h);
 		cflame.ix.type = PIT_PLANE;
 		break;
 	default:
@@ -608,9 +608,9 @@ int ofs,tar;
 /*
 	if ( cflame.ix.type == 0 ) {
 		cflame.ix.xy.index_x =
-			d_alloc(sizeof(int)*w,1235);
+			d_alloc(sizeof(int)*w);
 		cflame.ix.xy.index_y =
-			d_alloc(sizeof(int)*h,125);
+			d_alloc(sizeof(int)*h);
 		cflame.ix.type = PIT_XY;
 	}
 	else if ( cflame.ix.type != PIT_XY )
@@ -658,7 +658,7 @@ int ret;
 /*
 	if ( cflame.ix.type == 0 ) {
 		cflame.ix.p.index =
-			d_alloc(sizeof(VPOINT)*w*h,1235);
+			d_alloc(sizeof(VPOINT)*w*h);
 		cflame.ix.type = PIT_PLANE;
 	}
 	else if ( cflame.ix.type != PIT_XY )
@@ -718,7 +718,7 @@ GB_POINT _from,_to;
 /*
 	if ( cflame.ix.type == 0 ) {
 		cflame.ix.p.index =
-			d_alloc(sizeof(VPOINT)*w*h,1235);
+			d_alloc(sizeof(VPOINT)*w*h);
 		cflame.ix.type = PIT_PLANE;
 	}
 	else if ( cflame.ix.type != PIT_PLANE )
@@ -765,9 +765,9 @@ int ofs,tar;
 /*
 	if ( cflame.ix.type == 0 ) {
 		cflame.ix.xy.index_x =
-			d_alloc(sizeof(int)*w,1235);
+			d_alloc(sizeof(int)*w);
 		cflame.ix.xy.index_y =
-			d_alloc(sizeof(int)*h,125);
+			d_alloc(sizeof(int)*h);
 		cflame.ix.type = PIT_XY;
 	}
 	else if ( cflame.ix.type != PIT_XY )
@@ -2306,7 +2306,7 @@ char * page;
 		if ( check_event(cflame.im->header.win,
 			VE_BUTTON,VES_BUTTON_PRESS) )
 			return;
-		page = d_alloc(1000,67);
+		page = d_alloc(1000);
 		sprintf(page,"http://%s:%i/",
 			http_hostname,http_port);
 		set_change_page(page,1);
@@ -2436,7 +2436,7 @@ GBVIEW_STATUS sts;
 
 	call_wf_status(&sts,CALL_STS_CACHE_REFRESH);
 
-	sts.display = d = v_open_disp(&err);
+	env_display = d = v_open_disp(&err);
 
 	sts.flags = SF_DISPLAY;
 	call_wf_set_status(&sts);
@@ -2522,7 +2522,7 @@ interface_infolist_func(int type,GBVIEW_STATUS * sts)
 {
 INFO_LIST * il;
 char * page, * dir;
-	page = d_alloc(1000,1333);
+	page = d_alloc(1000);
 	sprintf(page,"http://%s:%i/sys/indicate.cgi?",
 		http_hostname,
 		http_port);
@@ -2550,7 +2550,7 @@ void
 interface_info_error_func()
 {
 char * page;
-	page = d_alloc(1000,133);
+	page = d_alloc(1000);
 	sprintf(page,"http://%s:%i/sys/error.html",
 		http_hostname,
 		http_port);
@@ -2571,7 +2571,7 @@ interface_info_func(int type,GBVIEW_STATUS * sts)
 }
 
 void
-interface_event_func(int type,void * w)
+interface_event_func(GBVIEW_FLAME * gf,int type,void * w)
 {
 	switch ( type ) {
 	case ET_REDRAW:
