@@ -21,12 +21,19 @@
 #include	"xl.h"
 #include	"rcache.h"
 #include	"memory_debug.h"
+#include	"gbview.h"
+#include	"win_flame.h"
+#include	"cosmos.h"
+
+extern COSMOS_FLAME	cflame;
 
 int
 _main(int argc,char ** argv)
 {
 int i;
 extern int view_agent_switch;
+GBVIEW_FLAME * gf;
+GBVIEW_STATUS sts;
 
 	if ( argc < 2 ) {
 		fprintf(stderr,"too few argment\n");
@@ -36,6 +43,13 @@ extern int view_agent_switch;
 		init_sg();
 
 		view_init(argc,argv);
+
+		gf = wf_new_gf();
+		wf_init_status(&sts);
+		sts.flags = SF_RADAR;
+		wf_set_status(gf,&sts);
+
+
 		init_http_server();
 		init_interface();
 		init_polling_class(gblisp_top_env0);
@@ -47,7 +61,6 @@ extern int view_agent_switch;
 			l_string(std_cm,"cache"));
 		enable_rcache(RCF_ALL);
 
-
 		open_control_port();
 		loading_file(0, l_string(std_cm,"local"), 1);
 
@@ -55,6 +68,11 @@ extern int view_agent_switch;
 			start_gbview();
 		end_sg();
 
+		wf_init_status(&sts);
+		sts.flags = SF_STATUS;
+		sts.status = GVFS_ACTIVE;
+		wf_set_status(gf,&sts);
+
 		event_task();
 	}
 	else if ( strcmp(argv[1],"i") == 0 ||
