@@ -205,7 +205,7 @@ int plen;
 	f = get_url_filepath(u);
 	plen = strlen(prefix);
 	len = l_strlen(f) + (slen = l_strlen(sys_path));
-	filename = d_alloc(sizeof(L_CHAR)*(len+plen+10),10);
+	filename = d_alloc(sizeof(L_CHAR)*(len+plen+10));
 	l_strcpy(filename,sys_path);
 	l_strcpy(&filename[slen],f);
 	l_strcpy(&filename[len],l_string(std_cm,prefix));
@@ -317,7 +317,7 @@ STREAM * st;
 XL_SEXP * lr, * gt;
 URL u;
 
-	get_url2(&u,path,1221);
+	get_url2(&u,path);
 	filename = get_access_path(&u,".mta");
 	free_url(&u);
 	if ( filename == 0 )
@@ -523,17 +523,17 @@ char * my_name;
 
 	if ( m->my_pri )
 		d_f_ree(m->my_pri);
-	get_url2(&u,filename,1222);
+	get_url2(&u,filename);
 	fp = get_url_filepath(&u);
 	free_url(&u);
 	t = get_xltime();
 	port = get_my_port();
 
-	my_name = d_alloc(100,12);
+	my_name = d_alloc(100);
 	get_localhostname(my_name);
 
 	len = l_strlen(fp) + 100 + strlen(my_name);
-	buf = d_alloc(sizeof(L_CHAR)*len,10);
+	buf = d_alloc(sizeof(L_CHAR)*len);
 	sprintf(buf,"%012o:%s:%i:%s",
 		t,my_name,port,n_string(std_cm,fp));
 	d_f_ree(my_name);
@@ -561,7 +561,7 @@ char * buf;
 	if ( d == 0 )
 		er_panic("set_my_pri_force");
 	len = 30 + l_strlen(my_name);
-	buf = d_alloc(sizeof(L_CHAR)*len,10);
+	buf = d_alloc(sizeof(L_CHAR)*len);
 	sprintf(buf,"%012o%s",d-1,n_string(std_cm,my_name));
 	if ( m->my_pri )
 		d_f_ree(m->my_pri);
@@ -576,7 +576,7 @@ get_my_pri_from_mpt(MAP_PATH_TABLE * t)
 	if ( t == 0 )
 		return 0;
 	for ( ; t->next ; t = t->next );
-	return ll_copy_str(t->ent[t->id].pri,1435);
+	return ll_copy_str(t->ent[t->id].pri);
 }
 
 
@@ -597,11 +597,11 @@ char * my_name;
 		return -1;
 	p1 ++;
 
-	my_name = d_alloc(100,12);
+	my_name = d_alloc(100);
 	get_localhostname(my_name);
 
 	buf1 = d_alloc(l_strlen(filename)*sizeof(L_CHAR) + 
-		strlen(my_name) + 20,23);
+		strlen(my_name) + 20);
 	port = get_my_port();
 	sprintf(buf1,"%s:%i:%s",my_name,port,n_string(std_cm,filename));
 	d_f_ree(my_name);
@@ -687,7 +687,7 @@ URL u;
 L_CHAR * fp;
 int ret;
 	if ( filename ) {
-		get_url2(&u,filename,1223);
+		get_url2(&u,filename);
 		fp = get_url_filepath(&u);
 		free_url(&u);
 	}
@@ -744,7 +744,7 @@ void
 test_err(char * str)
 {
 URL u;
-	get_url2(&u,l_string(std_cm,"/tokyo/meiji/Cood-Japan.crd"),1224);
+	get_url2(&u,l_string(std_cm,"/tokyo/meiji/Cood-Japan.crd"));
 	free_url(&u);
 	if ( mpi_h.next == (MAP_PATH_INFO*)&mpi_h )
 		return;
@@ -762,16 +762,16 @@ AROUND_LIST * ret, ** ap, * a1;
 	ret = 0;
 	ap = &ret;
 	for ( ; a ; a = a->next ) {
-		a1 = d_alloc(sizeof(*a1),26);
+		a1 = d_alloc(sizeof(*a1));
 		a1->next = 0;
 		if ( a->crd )
-			a1->crd = ll_copy_str(a->crd,547);
+			a1->crd = ll_copy_str(a->crd);
 		else	a1->crd = 0;
 		if ( a->map )
-			a1->map = ll_copy_str(a->map,37);
+			a1->map = ll_copy_str(a->map);
 		else	a1->map = 0;
 		if ( a->me )
-			a1->me = ll_copy_str(a->me,6);
+			a1->me = ll_copy_str(a->me);
 		else	a1->me = 0;
 		a1->mpt = 0;
 		*ap = a1;
@@ -822,10 +822,10 @@ XL_SEXP * r;
 
 		if ( map == 0 || src == 0 || dest == 0 )
 			continue;
-		aa = d_alloc(sizeof(*aa),1);
-		aa->map = ll_copy_str(map,1404);
-		aa->crd = ll_copy_str(src,1403);
-		aa->me = ll_copy_str(dest,1402);
+		aa = d_alloc(sizeof(*aa));
+		aa->map = ll_copy_str(map);
+		aa->crd = ll_copy_str(src);
+		aa->me = ll_copy_str(dest);
 		aa->mpt = 0;
 		aa->next = a;
 		a = aa;
@@ -837,10 +837,10 @@ XL_SEXP * r;
 		get_sd_url(&src,&dest,&map,r);
 		if ( map == 0 || src == 0 || dest == 0 )
 			continue;
-		aa = d_alloc(sizeof(*aa),1);
-		aa->map = ll_copy_str(map,1401);
-		aa->crd = ll_copy_str(dest,1400);
-		aa->me = ll_copy_str(src,1399);
+		aa = d_alloc(sizeof(*aa));
+		aa->map = ll_copy_str(map);
+		aa->crd = ll_copy_str(dest);
+		aa->me = ll_copy_str(src);
 		aa->mpt = 0;
 		aa->next = a;
 		a = aa;
@@ -860,7 +860,7 @@ L_CHAR * filename;
 	if ( mpi->alist_fetch == 0 ) {
 		unlock_task(mpi_lock,"get_mpi_around_all");
 
-		filename = ll_copy_str(get_url_str(&mpi->u),326);
+		filename = ll_copy_str(get_url_str(&mpi->u));
 		gc_push(0,0,"make_around_list");
 		chi = filtering_crd(get_crd_chi(filename));
 		par = filtering_crd(get_crd_par(filename));
@@ -876,6 +876,40 @@ L_CHAR * filename;
 	return a1;
 }
 
+int
+localhost_check(URL * up,L_CHAR * url_str,char * msg)
+{
+int local_ip;
+int p;
+L_CHAR nul[2] = {(L_CHAR)'*',0};
+	gc_push(0,0,"get_mpi1");
+	local_ip = get_localhostip();
+	p = get_my_port();
+	if ( url_str == 0 )
+		url_str = nul;
+	if ( cmp_site(up->server,0,up->port,
+			0,local_ip,p) ) {
+		log_printf(LOG_WARNING,
+			"(%s)get_mpi ses=0 REMOTE_CK %ls(%ls)\n",
+			msg,get_url_str2(up),url_str);
+		gc_pop(0,0);
+		return -1;
+	}
+	gc_pop(0,0);
+	return 0;
+}
+
+int
+localhost_check_str(L_CHAR * url_str,char *msg)
+{
+URL u;
+int ret;
+	get_url2(&u,url_str);
+	ret = localhost_check(&u,url_str,msg);
+	free_url(&u);
+	return ret;
+}
+
 
 MAP_PATH_INFO *
 get_mpi(int ses,L_CHAR * url_str,int type)
@@ -903,7 +937,7 @@ set_cpu_msg(730010);
 set_cpu_msg(730020);
 	p = get_my_port();
 set_cpu_msg(730021);
-	get_url2(&u,url_str,1225);
+	get_url2(&u,url_str);
 set_cpu_msg(730022);
 	lock_task(mpi_lock);
 set_cpu_msg(730023);
@@ -911,7 +945,7 @@ set_cpu_msg(730023);
 		u.proto = nl_copy_str(std_cm,"xlp");
 set_cpu_msg(730024);
 	if ( u.server == 0 )
-		u.server = ll_copy_str(gblisp_site,1434);
+		u.server = ll_copy_str(gblisp_site);
 set_cpu_msg(730025);
 	if ( u.port == 0 )
 		u.port = p;
@@ -920,7 +954,7 @@ set_cpu_msg(730030);
 	L_CHAR * buf;
 	int len;
 		len = l_strlen(u.db);
-		buf = d_alloc(sizeof(L_CHAR)*(len+2),23);
+		buf = d_alloc(sizeof(L_CHAR)*(len+2));
 		l_strcpy(&buf[1],u.db);
 		buf[0] = '/';
 		d_f_ree(u.db);
@@ -997,9 +1031,22 @@ set_cpu_msg(730090);
 	return m;
 
 no_fit:
+	gc_push(0,0,"get_mpi1");
+	local_ip = get_localhostip();
+	if ( cmp_site(u.server,0,u.port,
+			0,local_ip,p) && ses == 0 ) {
+	  	unlock_task(mpi_lock,"get_mpi1");
+		log_printf(LOG_WARNING,"get_mpi ses=0 REMOTE %ls(%ls)\n",
+			get_url_str2(&u),url_str);
+		free_url(&u);
+		gc_pop(0,0);
+		return 0;
+	}
+	gc_pop(0,0);
+
 
 set_cpu_msg(730100);
-	m = d_alloc(sizeof(*m),1002);
+	m = d_alloc(sizeof(*m));
 	m->alist_fetch = 0;
 	m->alist = 0;
 	m->u = u;
@@ -1033,28 +1080,16 @@ set_cpu_msg(730120);
 	local_ip = get_localhostip();
 	if ( cmp_site(u.server,0,u.port,
 			0,local_ip,p) == 0 ) {
-set_cpu_msg(730130);
 		ret = local_fetch(&mod,&u,".mpt");
 		m->modify = mod;
 		sts = MPIS_LOCAL;
-set_cpu_msg(730140);
 	}
 	else if ( ses ) {
-set_cpu_msg(730150);
 	 	ret = remote_fetch(ses,&u);
 		sts = MPIS_REMOTE;
-set_cpu_msg(730160);
 	}
 	else {
-set_cpu_msg(730170);
-		lock_task(mpi_lock);
-		delete_mpi_ring(m);
-		free_mpi(m);
-		mpi_list_length --;
-		unlock_task(mpi_lock,"get_mpi");
-		gc_pop(0,0);
-set_cpu_msg(730180);
-		return 0;
+		er_panic("get_mpi");
 	}
 set_cpu_msg(730190);
 
@@ -1264,7 +1299,7 @@ int i;
 int ses;
 XL_SEXP * gt;
 
-	get_url2(&u,url,1219);
+	get_url2(&u,url);
 	port = get_my_port();
 	ip = get_localhostip();
 	ses = open_session(SEST_OPTIMIZE);
@@ -1273,7 +1308,7 @@ XL_SEXP * gt;
 		return 0;
 	t1 = t;
 	for ( len = 0 ; t1 ; t1 = t1->next , len ++ );
-	ret = d_alloc(sizeof(int)*(len+1),1);
+	ret = d_alloc(sizeof(int)*(len+1));
 	t1 = t;
 	for ( i = 1 ; i <= len ; i ++ , t1 = t1->next )
 		ret[i] = t1->id;
@@ -1290,7 +1325,7 @@ mpi_purge(L_CHAR * str)
 {
 URL u;
 MAP_PATH_INFO * m;
-	get_url2(&u,str,1220);
+	get_url2(&u,str);
 	if ( u.server == 0 && u.port == 0 )
 		u.port = get_my_port();
 	lock_task(mpi_lock);
