@@ -1629,7 +1629,9 @@ CHAIN_LIST * c;
 	ret->c.flags = cr->flags;
 	ret->c.geometory_type = cr->geometory_type;
 	ret->c.geometory_param = 0;/***/
-	ret->c.limit_resolution = cr->limit_resolution;
+	if ( ret->c.flags & CF_FIX_LIMIT_RESO )
+		ret->c.limit_resolution = cr->limit_resolution;
+	else	ret->c.limit_resolution = 0;
 	ret->c.ov = search_overlay(&ret->h.entry);
 	if ( ret->c.ov == 0 )
 		ret->c.ov = &default_overlay;
