@@ -191,7 +191,7 @@ ACC_PN_RT_CACHE_HEADER * h;
 		return;
 	if ( rt_cache_header == 0 )
 		return;
-	h = d_alloc(sizeof(ACC_PN_RT_CACHE_HEADER),22);
+	h = d_alloc(sizeof(ACC_PN_RT_CACHE_HEADER));
 	*h = *rt_cache_header;
 	change_endian_rt_cache_header(&h->d);
 	write_filespace(rc_p,h);
@@ -215,7 +215,7 @@ int ret;
 	if ( p == 0 )
 		return -1;
 	ret = -1;
-	h = d_alloc(sizeof(*h),1);
+	h = d_alloc(sizeof(*h));
 	h->h.fofs = 0;
 	h->d.h.size = sizeof(h->d);
 	h->d.h.type = PNT_RT_CACHE_HEADER;
@@ -273,7 +273,7 @@ retry:
 			close_filespace(rc_p);
 			goto remake;
 		}
-		rt_cache_header = d_alloc(sizeof(*rt_cache_header),33);
+		rt_cache_header = d_alloc(sizeof(*rt_cache_header));
 		rt_cache_header->d = *h;
 		rt_cache_header->h.fofs = fofs;
 		d_f_ree(h);
@@ -343,7 +343,7 @@ int len;
 
 	len = l_strlen(url);
 
-	ix = d_alloc(STRING_IX_LENGTH_1(len),123);
+	ix = d_alloc(STRING_IX_LENGTH_1(len));
 	ix->fofs = 0;
 	l_strcpy(ix->d,url);
 	n = favt_search(r,root_node(r),ix,favt_cmp_string_1);
@@ -373,7 +373,7 @@ int len,_len;
 	change_endian_rt_cache_data_to_host(&d->d);
 	if ( routing_cache.err == RE_DESTROY )
 		return 0;
-	ret = d_alloc(sizeof(*ret),22);
+	ret = d_alloc(sizeof(*ret));
 	memset(ret,0,sizeof(*ret));
 	ret->sts = RS_COPY;
 	ret->update = d->d.update;
@@ -381,8 +381,8 @@ int len,_len;
 	ptr = (L_CHAR*)((&d->d)+1);
 	len = d->d.h.size - sizeof(d->d);
 	for ( ; len > 0 ; ) {
-		p = d_alloc(sizeof(*p),33);
-		p->url = ll_copy_str(ptr,11);
+		p = d_alloc(sizeof(*p));
+		p->url = ll_copy_str(ptr);
 		p->next = 0;
 		if ( ret->head == 0 ) {
 			ret->head = ret->tail = p;
@@ -417,7 +417,7 @@ RT_CACHE_LIST * n;
 	len = lst->d.h.size - sizeof(lst->d);
 	ptr = (PN_RT_CACHE_ELEMENT*)((&lst->d)+1);
 	for ( i = 0 ; i < len/sizeof(PN_RT_CACHE_ELEMENT) ; i ++ , ptr ++ ) {
-		n = d_alloc(sizeof(*n),33);
+		n = d_alloc(sizeof(*n));
 		n->el = *ptr;
 		n->next = 0;
 		*pos = n;
@@ -478,13 +478,12 @@ unsigned int ret;
 	d_len = len / RT_MAX_LIST_LEN;
 	if ( len % RT_MAX_LIST_LEN )
 		d_len ++;
-	d = d_alloc(sizeof(*d) * d_len , 333);
+	d = d_alloc(sizeof(*d) * d_len);
 	for ( i = 0 ; i < d_len ; i ++ ) {
 		if ( len > RT_MAX_LIST_LEN )
 			size = RT_MAX_LIST_LEN;
 		else	size = len;
-		d[i] = d_alloc(PN_RT_CACHE_LIST_S(size) + sizeof(ACC_HEADER),
-				22);
+		d[i] = d_alloc(PN_RT_CACHE_LIST_S(size) + sizeof(ACC_HEADER));
 		d[i]->h.fofs = 0;
 		d[i]->d.next = 0;
 		ep = (PN_RT_CACHE_ELEMENT*)((&d[i]->d)+1);
@@ -785,7 +784,7 @@ int ret;
 	size = sizeof(d->d);
 	for ( p = mp->head ; p ; p = p->next )
 		size += (l_strlen(p->url)+1)*sizeof(L_CHAR);
-	d = d_alloc(size+sizeof(ACC_HEADER),222);
+	d = d_alloc(size+sizeof(ACC_HEADER));
 	d->d.h.type = PNT_RT_CACHE_DATA;
 	d->d.h.size = size;
 	d->d.update = mp->update;
@@ -824,7 +823,7 @@ STRING_INDEX * ix;
 	ixd = get_rt_url(&n,r,url);
 	if ( ixd == 0 ) {
 		len = l_strlen(url);
-		ix = d_alloc(STRING_IX_LENGTH_1(len),22);
+		ix = d_alloc(STRING_IX_LENGTH_1(len));
 		ix->fofs = 0;
 		l_strcpy(ix->d,url);
 		n = favt_alloc_node(r,ix,STRING_IX_LENGTH_1(len));
@@ -842,7 +841,7 @@ STRING_INDEX * ix;
 	else {
 		lst1 = get_rt_cache_list(ixd);
 	}
-	ins = d_alloc(sizeof(*ins),22);
+	ins = d_alloc(sizeof(*ins));
 	ins->el = *el;
 	p1 = &lst1;
 	for ( ; *p1 ; p1 = &(*p1)->next ) {
