@@ -84,7 +84,7 @@ int lod;
 SCAN_LIST * sl2;
 SCAN_WORK w;
 
-	lock_pdb_lock(r,4);
+	lock_pdb_lock(r,0);
 	w.sl = 0;
 	w.r = r;
 	avt_trace_from_small(r->draw_gb.obj_code_tree,
@@ -105,7 +105,7 @@ scan_dm_point_list(DRAW_MATRIX * dm)
 POINT_LIST * p;
 OBJ * obj;
 printf("scan_dm_point\n");
-	lock_pdb_lock(dm->r,5);
+	lock_pdb_lock(dm->r,0);
 	for ( ; dm->dm_point_list ; ) {
 		p = dm->dm_point_list;
 		dm->dm_point_list = p->dm_next;
@@ -221,7 +221,7 @@ int i;
 	sscanf(n_string(std_cm,id),"%i",&_id);
 	type = get_sf_attribute(sf,l_string(std_cm,"type"));
 
-	lock_pdb_lock(r,6);
+	lock_pdb_lock(r,0);
 	obj = search_obj(r,_id);
 	if ( obj == 0 ) {
 		obj = new_object(r,OT_POLYGON2D,_id);
@@ -764,6 +764,7 @@ end:
 
 int
 draw_polygon2d(
+	GBVIEW_FLAME * gf,
 	OBJ * o,
 	DRAW_WORK * dw)
 {
@@ -778,32 +779,24 @@ int inside_rect_flag;
 int cnt;
 
 
-dw->resource->draw_gb.pdb_lock_msg = 820;
 	if ( dw->method == 0 )
 		return 0; 
 
-dw->resource->draw_gb.pdb_lock_msg = 821;
 
 	if ( dw->pixels && o->polygon2d.type == PT_CLOSE &&
 			o->h.palette.padding_color.t != 0 ) {
 		padding(&ind,o,dw);
 	}
 
-dw->resource->draw_gb.pdb_lock_msg = 822;
-
 	if ( o->h.palette.line_color.t == 0 )
 		return 0;
 
-dw->resource->draw_gb.pdb_lock_msg = 823;
-
 	p = lod_next((POINT_LIST*)&o->polygon2d.point_list,
 		&o->polygon2d.point_list,dw->draw_lod,&dw->draw_rect);
 	if ( p == lod_prev((POINT_LIST*)&o->polygon2d.point_list,
 		&o->polygon2d.point_list,dw->draw_lod,&dw->draw_rect) )
 		return 0;
 
-dw->resource->draw_gb.pdb_lock_msg = 824;
-
 	p1 = p->pt;
 	er = 1;
 	map_conv_forward(dw->map->map_file,&p1,&er,1);
@@ -822,8 +815,6 @@ dw->resource->draw_gb.pdb_lock_msg = 824;
 	if ( er < 0 )
 		return -1;
 
-dw->resource->draw_gb.pdb_lock_msg = 825;
-
 	if ( o->polygon2d.type == PT_CLOSE )
 		last = p1;
 	else {
@@ -836,16 +827,12 @@ dw->resource->draw_gb.pdb_lock_msg = 825;
 		if ( er < 0 )
 			return -1;
 	}
-dw->resource->draw_gb.pdb_lock_msg = 826;
-
 	p_prev = p;
 	for ( p = lod_next(p,&o->polygon2d.point_list,
 			dw->draw_lod,&dw->draw_rect);
 		p != (POINT_LIST*)&o->polygon2d.point_list;
 		p = lod_next(p,&o->polygon2d.point_list,
 			dw->draw_lod,&dw->draw_rect) ) {
-dw->resource->draw_gb.pdb_lock_msg = 827;
-
 		p2 = p->pt;
 		er = 1;
 		map_conv_forward(dw->map->map_file,&p2,&er,1);
@@ -868,7 +855,6 @@ dw->resource->draw_gb.pdb_lock_msg = 827;
 		else {
 			inside_rect_flag = 0;
 		}
-dw->resource->draw_gb.pdb_lock_msg = 828;
 		if ( er == -1 )
 			return -1;
 		if (  !(p_prev->no & PP_LMOVE) &&
@@ -885,9 +871,7 @@ dw->resource->draw_gb.pdb_lock_msg = 828;
 					dw->rectondisp->tl.x);
 		p1 = p2;
 		p_prev = p;
-dw->resource->draw_gb.pdb_lock_msg = 829;
 	}
-dw->resource->draw_gb.pdb_lock_msg = 830;
 	if ( dw->pixels && (p2.x != last.x || p2.y != last.y) &&
 		!(p_prev->no & PP_LMOVE) )
 		line_to(dw->pixels,p2,last,
@@ -897,7 +881,6 @@ dw->resource->draw_gb.pdb_lock_msg = 830;
 			dw->rectondisp->br.y-dw->rectondisp->tl.y,
 			dw->rectondisp->br.x-dw->rectondisp->tl.x);
 
-dw->resource->draw_gb.pdb_lock_msg = 831;
 	if ( ind_cnt ) {
 	int size;
 		ind.x = ind.x/ind_cnt;
@@ -908,10 +891,9 @@ dw->resource->draw_gb.pdb_lock_msg = 831;
 			if ( (o->h.flags & OF_INFO_STS) != OF_INFO_FETCH )
 				o->h.flags |= OF_ONMAP_REQ;
 
-			indicate_onmap(1,dw->wfid,dw->resource,o,ind);
+			indicate_onmap(gf,1,dw->wfid,dw->resource,o,ind);
 		}
 	}
-dw->resource->draw_gb.pdb_lock_msg = 832;
 	return 0;
 }
 
@@ -958,6 +940,7 @@ REAL1 x;
 
 int
 get_point_polygon2d(
+	GBVIEW_FLAME * gf,
 	RESOURCE * r,
 	OBJ * o,
 	GET_POINT_WORK * w)
@@ -1028,7 +1011,7 @@ int fg,fg2,fg3;
 	if ( (cnt & 1) == 0  )
 		return 0;
 	if ( w->button == GPB_PRESS )
-		indicate_info_card(r,o);
+		indicate_info_card(gf,r,o);
 	return 1;
 }
 
