@@ -534,6 +534,9 @@ draw_draw_gb(
 OBJ * o;
 int i;
 GB_RECT rct;
+GB_RECT * rp;
+int rp_len;
+int rr;
 double reso,reso2;
 int lev;
 GB_POINT pt;
@@ -541,61 +544,70 @@ int size;
 RT_OBJ_LIST * ol, * olp, ** olpp;
 GB_RECT min,max;
 REAL1 serf1,serf2;
-
+double pitch;
 int olcnt;
 
 	if ( dw->method == 0 )
 		return; 
-	rct = get_surp_rect_rate(&dw->surp,0.1,r);
-	dw->draw_rect = rct;
-	dw->draw_lod = 0;
+	rp = get_surp_rect_rate(&rp_len,&dw->surp,0.1,0);
+	for ( rr = 0 ; rr < rp_len ; rr ++ )  {
+		rct = rp[rr];
 
-	dw->limit_reso = r->draw_gb.resolution; 
-	dw->limit_ptr = p_add(rct.tl,rct.br);
-	dw->limit_ptr.x /= 2;
-	dw->limit_ptr.y /= 2;
+		dw->draw_rect = rct;
+		dw->draw_lod = 0;
 
-	if ( lock_pdb_lock(r,1) < 0 )
-		return;
+		dw->limit_reso = r->draw_gb.resolution; 
+		dw->limit_ptr = p_add(rct.tl,rct.br);
+		dw->limit_ptr.x /= 2;
+		dw->limit_ptr.y /= 2;
 
-	if ( r->draw_gb.type == DGT_LOAD )
-		goto draw;
-	reso2 = r->draw_gb.resolution;
-	reso = get_surp_reso(&dw->surp);
+		if ( lock_pdb_lock(r,1) < 0 )
+			continue;
+
+		if ( r->draw_gb.type == DGT_LOAD )
+			goto draw;
+		reso2 = r->draw_gb.resolution;
+		reso = get_surp_reso(&dw->surp);
 /*
 	if ( reso > reso2*LIMIT_RESOLUTION_RATE )
 		goto end;
 */
-	for ( lev = 0; lev < r->draw_gb.level ; lev ++, reso2 = reso2/2 )
-		if ( reso > reso2*PDB_RESO )
-			break;
-	r->draw_gb.hit_level = lev;
-	if ( lev == r->draw_gb.level )
-		goto end;
-	r->draw_gb.loop_no ++;
-	digging_matrix(dw->wfid,r,&rct,lev);
-	dw->draw_lod = lev;
+		for ( lev = 0; lev < r->draw_gb.level ; lev ++, reso2 = reso2/2 )
+			if ( reso > reso2*PDB_RESO )
+				break;
+		r->draw_gb.hit_level = lev;
+		if ( lev == r->draw_gb.level )
+			goto end;
+		r->draw_gb.loop_no ++;
+		pitch = ((rct.br.x - rct.tl.x)/r->draw_gb.pitch_list[lev].x) *
+				((rct.br.y - rct.tl.y)/r->draw_gb.pitch_list[lev].y );
+		if ( pitch > 1000 ) {
+ss_printf("PITCH WARNING ============================ %f",pitch);
+			for ( ; pitch > 1000 ; pitch /= 2 , lev ++ );
+		}
+		digging_matrix(dw->wfid,r,&rct,lev);
+		dw->draw_lod = lev;
 
-draw:
+	draw:
 
-	serf1 = (rct.br.x - rct.tl.x)*(rct.br.y - rct.tl.y);
-	serf2 = (r->h.minrect.br.x - r->h.minrect.tl.x)*
-			(r->h.minrect.br.y - r->h.minrect.tl.y);
-	min.tl.x = r->h.minrect.tl.x;
-	min.tl.y = r->h.minrect.tl.y;
-	min.br.x = rct.tl.x;
-	min.br.y = rct.tl.y;
+		serf1 = (rct.br.x - rct.tl.x)*(rct.br.y - rct.tl.y);
+		serf2 = (r->h.minrect.br.x - r->h.minrect.tl.x)*
+				(r->h.minrect.br.y - r->h.minrect.tl.y);
+		min.tl.x = r->h.minrect.tl.x;
+		min.tl.y = r->h.minrect.tl.y;
+		min.br.x = rct.tl.x;
+		min.br.y = rct.tl.y;
 
-	max.tl.x = rct.br.x;
-	max.tl.y = rct.br.y;
-	max.br.x = r->h.minrect.br.x;
-	max.br.y = r->h.minrect.br.y;
+		max.tl.x = rct.br.x;
+		max.tl.y = rct.br.y;
+		max.br.x = r->h.minrect.br.x;
+		max.br.y = r->h.minrect.br.y;
 
-	ol = search_rect_tree(&r->draw_gb.obj_rect_tree,
-		&min,&max);
+		ol = search_rect_tree(&r->draw_gb.obj_rect_tree,
+			&min,&max);
 
 
-	dw->resource = r;
+		dw->resource = r;
 /*
 printf("r minrect (%f %f) - (%f %f)\n",
 r->h.minrect.tl.x,
@@ -609,36 +621,36 @@ rct.br.x,
 rct.br.y);
 */
 
-	for ( olpp = &ol ; *olpp ;) {
-		o = (*olpp)->obj;
-		if ( o->h.lod_min < 0 ) {
-			olpp = &(*olpp)->next;
-			continue;
+		for ( olpp = &ol ; *olpp ;) {
+			o = (*olpp)->obj;
+			if ( o->h.lod_min < 0 ) {
+				olpp = &(*olpp)->next;
+				continue;
+			}
+			else if ( o->h.lod_min <= lev &&
+					lev <= o->h.lod_max ) {
+				olpp = &(*olpp)->next;
+				continue;
+			}
+			olp = *olpp;
+			*olpp = olp->next;
+			olp->next = 0;
+			free_rt_obj_list(olp);
 		}
-		else if ( o->h.lod_min <= lev &&
-				lev <= o->h.lod_max ) {
-			olpp = &(*olpp)->next;
-			continue;
+
+
+		ol = sort_obj_list(ol);
+	check_obj_list(ol);
+		for ( olp = ol ; olp ; olp = olp->next ) {
+			draw_object(gf,olp->obj,dw);
+			dw->flags |= WFF_DRAW;
 		}
-		olp = *olpp;
-		*olpp = olp->next;
-		olp->next = 0;
-		free_rt_obj_list(olp);
+
+		free_rt_obj_list(ol);
+	end:
+
+		unlock_pdb_lock(r);
 	}
-
-
-	ol = sort_obj_list(ol);
-check_obj_list(ol);
-	for ( olp = ol ; olp ; olp = olp->next ) {
-		draw_object(gf,olp->obj,dw);
-		dw->flags |= WFF_DRAW;
-	}
-
-	free_rt_obj_list(ol);
-end:
-
-	unlock_pdb_lock(r);
-
 }
 
 
