@@ -652,13 +652,11 @@ int sub;
 			o->h.onmap_resolution > o->h.req_resolution )
 		return;
 /*
-if ( r->h.no == 196617 ){
-printf("onmap = %i %i ",
+ss_printf("onmap = %i %i ",
 r->h.no,
 o->h.code>>8);
 print_sexp(s_stdout,o->h.info_onmap,0);
-printf("\n");
-}
+ss_printf("\n");
 */
 	pic = get_onmap_string_pic(o->h.info_onmap);
 	if ( pic.list == 0 ){
@@ -967,6 +965,7 @@ XL_SEXP * info_org;
 OBJ * o;
 XL_SEXP * card_data;
 
+
 	info_org = info;
 	v = car(info);
 	for ( sf = v->symbol.field ; sf;
