@@ -74,7 +74,7 @@ next:
 */
 	new_tick(pixel_gc_tick,1,0);
 }
-
+/*int *debug_chace=0;*/
 void
 gv_new_luster_option(RESOURCE * r,int r64_level)
 {
@@ -92,7 +92,11 @@ int ses;
 	case '2':
 		init_tc(ses,&r->pr64.tc,r64_level,RECT_LOGSIZE,
 			get_pixel_cr,get_query_cr,r);
-		break;
+/*		
+		if(debug_chace==0){
+			debug_chace = &(r->pr64.tc.cache);
+		}
+*/		break;
 	default:
 		er_panic("gv_new_luster_option(1)");
 	}
