@@ -43,6 +43,7 @@ typedef struct raw_image {
 #define RIE_REQ		1
 #define RIE_ERR		-1
 	WF_ID			request;
+	GBVIEW_FLAME *		request_gf;
 	struct raw_image *	next;
 } RAW_IMAGE;
 
@@ -71,7 +72,7 @@ int ri_cmp(RAW_IMAGE * ri1,RAW_IMAGE * ri2)
 }
 
 void
-_insert_ri(WF_ID req,L_CHAR * path,void * data,int w,int h)
+_insert_ri(GBVIEW_FLAME * gf,WF_ID req,L_CHAR * path,void * data,int w,int h)
 {
 AVT_NODE * a1, * a2;
 RAW_IMAGE * ri;
@@ -83,6 +84,7 @@ int size;
 	ri->height = h;
 	ri->err = RIE_REQ;
 	ri->request = req;
+	ri->request_gf = gf;
 	ri->ndata = 0;
 	ri->ndata_len = 0;
 	if ( data ) {
@@ -381,9 +383,10 @@ int s;
 		wakeup_task((int)ri);
 		unlock_task(ri_lock,"get_ri");
 		if ( ri->request ) {
-			win_flame_dirty(ri->request,0,
+			win_flame_dirty(ri->request_gf,ri->request,0,
 				WFF_PLOT_DIRTY,0);
 			ri->request = 0;
+			ri->request_gf = 0;
 		}
 
 		lock_task(ri_lock);
@@ -399,7 +402,7 @@ int s;
 
 
 void *
-get_ri(int * w,int * h,WF_ID req,L_CHAR * path)
+get_ri(int * w,int * h,GBVIEW_FLAME * gf,WF_ID req,L_CHAR * path)
 {
 RAW_IMAGE * rip;
 void * data;
@@ -407,7 +410,7 @@ RAW_IMAGE * ri;
 	lock_task(ri_lock);
 	rip = _search_ri(path);
 	if ( rip == 0 ) {
-		_insert_ri(req,path,0,0,0);
+		_insert_ri(gf,req,path,0,0,0);
 		wakeup_task((int)&ri_root);
 		data = 0;
 		goto end;
@@ -432,7 +435,7 @@ search_ri_org(int * len,L_CHAR * path)
 void * ret;
 int w,h;
 RAW_IMAGE * rip;
-	get_ri(&w,&h,0,path);
+	get_ri(&w,&h,0,0,path);
 	lock_task(ri_lock);
 	ret = _search_ri_org(len,path);
 	unlock_task(ri_lock,"search_ri_org");
