@@ -142,7 +142,7 @@ RESOURCE * r;
 printf("NEW %f %f - %f\n",new_center.x,new_center.y,new_rotate);
 	gf->flame_base_center = new_center;
 	gf->flame_base_rotate = new_rotate;
-	calc_pitch(gf,1);
+	_calc_pitch(gf,1);
 	return 0;
 }
 
