@@ -2914,7 +2914,8 @@ wf_insert_dirty_rect(RESOURCE * r,GB_RECT * d_rect,
 SURP_SET ss;
 MAP_HISTORY * mh;
 RESOURCE * draw;
-GB_RECT rct;
+GB_RECT rct,* _rct;
+int nos;
 RESOURCE * map;
 WFID_INCLUDE_RESOURCE * wir,* p;
 	wir = wf_search_wfid_include_resource(r);
@@ -2922,17 +2923,23 @@ if ( r->h.target.port == 9000 )
 ss_printf("********DIRTY 1 %x\n",wir);
 	for ( p = wir ; p ; p = p->next ) {
 		if ( p->id == 0 )
-			return;
+			continue;
 		set_surp(&ss,d_rect,1);
 		draw = wf_get_mh(p->gf,p->id,&mh);
 		if ( draw == 0 )
-			return;
+			continue;
 		map = get_map_between2(r,draw);
 		if ( map == 0 )
-			return;
+			continue;
 		map_conv_forward(map,ss.ptr,ss.reso,SURP_NOS);
 		map_from_resource(mh,ss.ptr,ss.reso,SURP_NOS);
-		rct = get_surp_rect(&ss,0);
+		memset(ss.group,0,sizeof(ss.group));
+		_rct = get_surp_rect(&nos,&ss,0);
+		if ( nos > 1 )
+			er_panic("wf_insert_dirty_rect");
+		if ( nos == 0 )
+			continue;
+		rct = *_rct;
 
 		rct.tl.x -= ofs_w;
 		rct.tl.y -= ofs_h;
