@@ -30,6 +30,19 @@ char * ptr;
 }
 
 
+void
+wf_free_layer_status(GBVIEW_LAYER_STATUS * ls)
+{
+GBVIEW_LAYER_STATUS * ls_1;
+	for ( ; ls ; ) {
+		ls_1 = ls->next;
+		d_f_ree(ls->entry_url);
+		d_f_ree(ls->target_url);
+		d_f_ree(ls);
+		ls = ls_1;
+	}
+}
+
 void
 wf_free_status(GBVIEW_STATUS * e)
 {
@@ -40,6 +53,7 @@ wf_free_status(GBVIEW_STATUS * e)
 	e->infolist = 0;
 	e->indicate = 0;
 	e->flags = 0;
+	wf_free_layer_status(e->layers);
 }
 
 
