@@ -133,7 +133,7 @@ void gc_gb_sexp();
 XL_SEXP * r;
 
 	gc_push(0,0,"get_mapping");
-	get_url2(&u,filename,1234);
+	get_url2(&u,filename);
 	buf = get_url_filepath(&u);
 	free_url(&u);
 	len = l_strlen(buf);
@@ -312,7 +312,7 @@ STREAM * st;
 			-1);
 	slen = l_strlen(sys_path);
 	len = l_strlen(filename);
-	_filename = d_alloc((len + slen + 10)*sizeof(L_CHAR),12);
+	_filename = d_alloc((len + slen + 10)*sizeof(L_CHAR));
 	l_strcpy(_filename,sys_path);
 	if ( filename[0] == '/' ) {
 		l_strcpy(&_filename[slen],filename);
@@ -362,7 +362,7 @@ XL_SEXP * gv;
 
 	slen = l_strlen(sys_path);
 	len = l_strlen(filename);
-	_filename = d_alloc((len + slen + 10)*sizeof(L_CHAR),12);
+	_filename = d_alloc((len + slen + 10)*sizeof(L_CHAR));
 	l_strcpy(_filename,sys_path);
 	if ( filename[0] == '/' ) {
 		l_strcpy(&_filename[slen],filename);
@@ -416,11 +416,11 @@ int len;
 	set_attribute(gt,
 		l_string(std_cm,"option"),
 		l_string(std_cm,"part"));
-	_target = ll_copy_str(target,1394);
+	_target = ll_copy_str(target);
 	len = l_strlen(_target);
 	_target = d_re_alloc(_target,(len+10)*sizeof(L_CHAR));
 	l_strcpy(&_target[len],l_string(std_cm,prefix));
-	get_url2(&u,_target,1235);
+	get_url2(&u,_target);
 	d_f_ree(_target);
 	ret = remote_session(
 		gblisp_top_env0,
@@ -482,11 +482,11 @@ int len;
 	set_attribute(gt,
 		l_string(std_cm,"option"),
 		l_string(std_cm,"delete"));
-	_target = ll_copy_str(target,1393);
+	_target = ll_copy_str(target);
 	len = l_strlen(_target);
 	_target = d_re_alloc(_target,(len+10)*sizeof(L_CHAR));
 	l_strcpy(&_target[len],l_string(std_cm,prefix));
-	get_url2(&u,_target,1233);
+	get_url2(&u,_target);
 printf("target %s\n",n_string(std_cm,_target));
 	d_f_ree(_target);
 	ret = remote_session(
@@ -528,7 +528,7 @@ int len;
 L_CHAR * ret;
 	port = get_my_port();
 	len = l_strlen(gblisp_site);
-	my_url = d_alloc(100+len,1);
+	my_url = d_alloc(100+len);
 	if ( current[0] == '/' )
 		sprintf(my_url,"xlp://%s:%i%s",
 			n_string(std_cm,gblisp_site),port,
@@ -551,7 +551,7 @@ L_CHAR * ret;
 	port = get_my_port();
 	len = l_strlen(gblisp_site);
 	flen = l_strlen(current);
-	my_url = d_alloc(100+len+flen,1);
+	my_url = d_alloc(100+len+flen);
 	if ( current[0] == '/' )
 		sprintf(my_url,"xlp://%s:%i%s",
 			n_string(std_cm,gblisp_site),port,
