@@ -162,7 +162,7 @@ ss_printf("infofile = %s ",sw.infofilename);
 		info = init_parse(sw.info_file,
 			l_string(std_cm,sw.infofilename),
 			l_string(std_cm,sw.infofilename));
-		if ( info->h.file->st )
+		if ( info && info->h.file->st )
 			_q_xml_encoding(info,l_string(std_cm,sw.encoding));
 		
 		if ( get_type(info) != XLT_PAIR ) {
