@@ -28,7 +28,7 @@ extern char gv_flame_initial_done;
 VDISPLAY * env_display;
 
 void
-call_gv_flame_event(int type,void * w)
+call_gv_flame_event(GBVIEW_FLAME * gf,int type,void * w)
 {
 static XL_INTERPRETER * xli;
 XL_SEXP * ret;
