@@ -343,6 +343,7 @@ wf_space_check_si(
 	int		percent);
 
 WF_ID wf_get_current();
+void _calc_pitch(GBVIEW_FLAME *,int);
 void calc_pitch(GBVIEW_FLAME *,int);
 int cache_image(
 	GBVIEW_FLAME * gf,
@@ -504,6 +505,8 @@ void assert_ls_all(int flags);
 
 GBVIEW_FLAME * wf_get_gf_from_id(int);
 void wf_apply_all_gf(int (*func)(),void * work,int status,int lock_flag);
+void
+set_pointer_indicate(GBVIEW_FLAME * gf,int flags,URL * u);
 
 #endif
 
