@@ -18,7 +18,7 @@
 
 
 #include	<stdlib.h>
-#include	<zlib.h>
+#include	"zlib.h"
 #include	"xl_zlib.h"
 #include	"memory_debug.h"
 
