@@ -255,7 +255,7 @@ MEM_LIST * ml;
 	mh = mh - 1;
 	if ( mh->last_free_file || mh->last_free_line )
 		er_panic("xx_d_f_ree(1)");
-	_insert_free_info(ptr,file,line);
+/*	_insert_free_info(ptr,file,line);*/
 	mh->last_free_file = file;
 	mh->last_free_line = line;
 	ml = mh->mlp;
