@@ -154,7 +154,7 @@ extern int point_nos;
 	if ( p->lod_max != -1 )
 		er_panic("insert_half_plist(1)");
 	if ( half_plist == 0 ) {
-		half_plist = d_alloc(sizeof(PDB_PD_POINT*)*(point_nos+1),35);
+		half_plist = d_alloc(sizeof(PDB_PD_POINT*)*(point_nos+1));
 		half_plist_len = 2;
 		half_plist[0] = 0;
 		half_plist[1] = p;
@@ -665,7 +665,7 @@ int moveto_flag;
 int count;
 
 	VERIFY(point_nos)
-	reso_point_list = d_alloc(sizeof(PDB_PD_POINT*)*point_nos,252);
+	reso_point_list = d_alloc(sizeof(PDB_PD_POINT*)*point_nos);
 	rpl_len = 0;
 	memset(reso_point_list, 0, sizeof(PDB_PD_POINT*)*point_nos);
 count = 0;
