@@ -68,6 +68,8 @@ void XLoHTTP_task();
 S_TABLE s_XLoHTTP_table = {
 	'x',
 	0,
+	{0,0},
+	0,
 	s_error_stream,
 	s_close_XLoHTTP,
 	s_write_XLoHTTP,
@@ -138,7 +140,7 @@ void
 chunk_read_start(STREAM * s)
 {
 CHUNK_READ_LIST * list;
-	list = d_alloc(sizeof(CHUNK_READ_LIST),932);
+	list = d_alloc(sizeof(CHUNK_READ_LIST));
 	lock_task(chunk_read_lock);
 	list->next = chunk_read_list;
 	chunk_read_list = list;
@@ -311,7 +313,7 @@ int start;
 	ret = 0;
 	rp = &ret;
 	for ( ; ; ) {
-		str = d_alloc(1,1);
+		str = d_alloc(1);
 		p = 0;
 		start = 1;
 		for ( ; ; ) {
@@ -327,7 +329,7 @@ printf("%c",str[p]);
 			case '\n':
 				str[p] = 0;
 				if ( p ) {
-					b = d_alloc(sizeof(*b),123);
+					b = d_alloc(sizeof(*b));
 					b->str = str;
 					b->next = 0;
 					*rp = b;
@@ -348,7 +350,7 @@ printf("%c",str[p]);
 		}
 	next:
 		str[p] = 0;
-		b = d_alloc(sizeof(*b),123);
+		b = d_alloc(sizeof(*b));
 		b->str = str;
 		b->next = 0;
 		*rp = b;
@@ -603,9 +605,9 @@ int length, result;
 		break;
 	}
 
-	ret = d_alloc(sizeof(*ret),123);
+	ret = d_alloc(sizeof(*ret));
 	ret->h.tbl = &s_XLoHTTP_table;
-	ret->xoh.info = d_alloc(sizeof(*ret->xoh.info),123);
+	ret->xoh.info = d_alloc(sizeof(*ret->xoh.info));
 
 	ret->xoh.info->con_head = ret->xoh.info->con_tail = 0;
 	ret->xoh.info->flags = flags & XoH_F_MASK;
@@ -705,12 +707,12 @@ retry:
 
 	info->flags |= XoH_F_FLUSH;
 
-	r = d_alloc(sizeof(*r),123);
+	r = d_alloc(sizeof(*r));
 	r->seq = 0;
 	r->next = 0;
 
 	total = get_sbuf_data_size(&info->send,0);
-	buf = d_alloc(total+1,123);
+	buf = d_alloc(total+1);
 	copy_out_sbuf(&info->send,buf,total,0);
 	server = copy_str(info->proxy_server);
 	ip = info->proxy_ip;
