@@ -26,10 +26,9 @@
 extern SEM stream_lock;
 
 int
-s_exist(STREAM * s)
+_s_exist(STREAM * s)
 {
 int ret;
-	lock_task(stream_lock);
 	if ( s == 0 ) {
 		ret = 0;
 		goto end;
@@ -40,6 +39,17 @@ int ret;
 	}
 	ret = 1;
 end:
+	return ret;
+}
+
+int
+s_exist(STREAM * s)
+{
+int ret;
+	lock_task(stream_lock);
+	ret = _s_exist(s);
 	unlock_task(stream_lock,"s_exist");
 	return ret;
-}
\ No newline at end of file
+}
+
+
