@@ -28,11 +28,14 @@ void
 s_set_cm(STREAM * s,CODE_METHOD * cm)
 {
 	lock_task(stream_lock);
+	if ( s == 0 )
+		goto end;
 	if ( s->h.tbl ) {
 		(*s->h.cm->close)(0,s->h.cm_work);
 		s->h.cm = cm;
 		s->h.cm_work = (*s->h.cm->open)();
 	}
+end:
 	unlock_task(stream_lock,"s_set_cr");
 }
 
