@@ -32,7 +32,7 @@ char port_buf[20];
 	buf = d_alloc(
 		((u->db ? l_strlen(u->db) : 0) +
 		 (u->resource ? l_strlen(u->resource) : 0) + 100) *
-			sizeof(L_CHAR),1000);
+			sizeof(L_CHAR));
 	buf[0] = 0;
 	ptr = buf;
 db:
