@@ -466,6 +466,24 @@ XL_INTERPRETER * xli;
 	unlock_task(sem_xli_lex_lock,"xli_lex_result");
 }
 
+void
+_xli_page_feed(XL_INTERPRETER*xli)
+{
+	s_printf(xli->out,"\014\n");
+	s_set_cr(xli->out,1);
+	s_flush(xli->out);
+}
+
+void
+xli_page_feed(int iid)
+{
+XL_INTERPRETER * xli;
+	lock_task(xli_lock);
+	xli = _search_xli_id(iid);
+	_xli_page_feed(xli);
+	unlock_task(xli_lock,"xli_page_feed");
+}
+
 
 
 void
@@ -1443,130 +1461,101 @@ XL_INTERPRETER * xli;
 
 
 void
-__reply(STREAM * st,XL_INTERPRETER * xli,int line,XL_SEXP * ret)
+__reply(STREAM ** stp,XL_INTERPRETER * xli,int line,XL_SEXP * ret)
 {
 int sc;
 CODE_METHOD * cm1, * cm2, * cm3;
 L_CHAR code;
 
-set_t_msg(1010);
 	cm1 = 0;
 	if ( !(xli->flags & XIF_FIX_CODE) ) {
-set_t_msg(1011);
 		code = get_proper_code(ret,10);
 		if ( code == LCC_ASCII )
 			cm1 = 0;
 		else	cm1 = search_cm_by_lccode(code);
-set_t_msg(1012);
 	}
-set_t_msg(1013);
 
 	lock_xli_out(xli);
-set_t_msg(1014);
 
 	if ( !(xli->flags & XIF_FIX_CODE) ) {
-set_t_msg(1015);
 		if ( cm1 ) {
-			cm2 = s_get_cm(st);
+			cm2 = s_get_cm(*stp);
 			if ( cm2 == 0 )
 				cm2 = 0;
 			else if ( cm1 == cm2 ) {
 				cm2 = 0;
 			}
 			else {
-set_t_msg(1016);
-				s_printf(st,"&cx%x;",cm1->lccode);
-				s_set_cm(st,cm1);
-				s_printf(st,"\n");
-set_t_msg(1017);
+				s_printf(*stp,"&cx%x;",cm1->lccode);
+				s_set_cm(*stp,cm1);
+				s_printf(*stp,"\n");
 				lock_task(xli_lock);
-set_t_msg(1018);
 				xli->flags &= ~XIF_CODE_SYNC;
 				unlock_task(xli_lock,"__reply");
-set_t_msg(1019);
 			}
 		}
 		else	cm2 = 0;
 	}
 	else	cm2 = 0;
-set_t_msg(1020);
 
 	sc = xli->silent_cnt;
 	if ( xli->silent_cnt != -1 )
 		xli->silent_cnt = -1;
-set_t_msg(1021);
 
 	if ( xli->flags & XIF_CODE_SYNC ) {
-set_t_msg(1022);
 		lock_task(xli_lock);
-set_t_msg(1023);
 		cm3 = s_get_cm(xli->out);
 		if ( cm3 )
-			s_printf(st,"&cx%x;",cm3->lccode);
+			s_printf(*stp,"&cx%x;",cm3->lccode);
 		xli->flags &= ~XIF_CODE_SYNC;
 		unlock_task(xli_lock,"__reply");
 	}
-set_t_msg(1024);
 
 	if ( xli->result_flag )
-		s_printf(st,"<Result> %i ",line);
+		s_printf(*stp,"<Result> %i ",line);
 
-set_t_msg(1025);
-	print_sexp(st,ret,xli->ps_flags&(~PF_MULTI_ROOT));
-set_t_msg(1026);
+	if ( *stp )
+		print_sexp(*stp,ret,xli->ps_flags&(~PF_MULTI_ROOT));
 
 	if ( xli->result_flag )
-		s_printf(st,"</Result>\n");
-	else	s_printf(st,"\n");
-set_t_msg(1027);
-	s_flush(st);
-set_t_msg(1028);
+		s_printf(*stp,"</Result>\n");
+	else	s_printf(*stp,"\n");
+	s_flush(*stp);
 
 	if ( cm2 ) {
-		s_printf(st,"&cx%x;",cm2->lccode);
-		s_set_cm(st,cm2);
-		s_printf(st,"\n");
+		s_printf(*stp,"&cx%x;",cm2->lccode);
+		s_set_cm(*stp,cm2);
+		s_printf(*stp,"\n");
 	}
-set_t_msg(1029);
 
 	xli->silent_cnt = sc;
-set_t_msg(1030);
 
 	unlock_xli_out(xli);
-set_t_msg(1031);
 }
 
 void
 _reply(XL_INTERPRETER * xli,int line,XL_SEXP * ret)
 {
-set_t_msg(1000);
 	lock_task(xli_lock);
-set_t_msg(1001);
 	xli->flags |= XIF_CTO_LOCK;
 	unlock_task(xli_lock,"_reply");
-set_t_msg(1002);
 
 	if ( get_type(ret) == XLT_ERROR ) {
-set_t_msg(1003);
 		if ( (ret->err.code&XLE_VERB_MASK) == XLE_EXIT )
-			__reply(xli->out,xli,line,0);
+			__reply(&xli->out,xli,line,0);
 		else {
 			if ( xli->out )
-				__reply(xli->out,xli,line,ret);
+				__reply(&xli->out,xli,line,ret);
 			if ( xli->err && xli->err != xli->out )
-				__reply(xli->err,xli,line,ret);
+				__reply(&xli->err,xli,line,ret);
 		}
-set_t_msg(1004);
 	}
 	else if ( xli->out )
-		__reply(xli->out,xli,line,ret);
+		__reply(&xli->out,xli,line,ret);
 
-set_t_msg(1005);
 	lock_task(xli_lock);
-set_t_msg(1006);
 	xli->flags &= ~XIF_CTO_LOCK;
 	unlock_task(xli_lock,"_reply");
-set_t_msg(1007);
 }
 
 
