@@ -27,6 +27,8 @@
 
 extern SEM xli_lock;
 
+void gc_gblisp_env(XLISP_ENV *);
+
 
 int
 cmp_round(int a,int b)
@@ -510,13 +512,13 @@ XL_SEXP *
 local_eval(int seq_no,XL_SEXP * cmd_sexp)
 {
 XL_INTERPRETER * xli;
-XL_RESULT ** rp;
+XL_RESULT * rr;
 XL_SEXP * ret;
 int tid;
 int inp_line;
 XL_INTERPRETER * inp_interpreter;
 int err_type;
-
+XLISP_ENV * cenv;
 
 	lock_task(xli_lock);
 	xli = _get_my_xli();
@@ -528,9 +530,9 @@ int err_type;
 	}
 
 
-	for ( rp = &xli->result_head ; *rp ; rp = &(*rp)->next ) {
-		if ( cmp_round((*rp)->seq_from,seq_no) <= 0 &&
-				cmp_round((*rp)->seq_to,seq_no) > 0 )
+	for ( rr = xli->result_head ; rr ; rr = rr->next ) {
+		if ( cmp_round(rr->seq_from,seq_no) <= 0 &&
+				cmp_round(rr->seq_to,seq_no) > 0 )
 			goto ok;
 	}
 	err_type = 2;
@@ -542,11 +544,17 @@ ok:
 
 	inp_line = xli->inp_line;
 	inp_interpreter = xli->inp_interpreter;
-	xli->inp_line = (*rp)->remote_seq;
-	xli->inp_interpreter = (*rp)->inp_interpreter;
+	xli->inp_line = rr->remote_seq;
+	xli->inp_interpreter = rr->inp_interpreter;
+	cenv = rr->cur_env;
+
+	lock_mem();
+	gc_set_nl(cenv,gc_gblisp_env);
+	unlock_mem();
+
 	unlock_task(xli_lock,"local_eval");
 
-	ret = eval((*rp)->cur_env,cmd_sexp);
+	ret = eval(cenv,cmd_sexp);
 
 	lock_task(xli_lock);
 	xli->inp_line = inp_line;
