@@ -96,7 +96,7 @@ char * ret_str_c;
 			break;
 		cnt ++;
 	}
-	argv = d_alloc(sizeof(char*)*(cnt+1),177);
+	argv = d_alloc(sizeof(char*)*(cnt+1));
 	p = str;
 	i = 0;
 	for ( ; ; ) {
@@ -107,7 +107,7 @@ char * ret_str_c;
 			break;
 	}
 	argv[i] = 0;
-	ret_str_c = d_alloc(100,178);
+	ret_str_c = d_alloc(100);
 
 
 	if ( (xli->flags&XIF_ASYNC) == 0 ) {
