@@ -25,6 +25,8 @@ mversion
 #include	<fcntl.h>
 #include	<time.h>
 
+
+
 typedef struct str_list {
 	struct str_list *	next;
 	char *			str;
@@ -82,6 +84,23 @@ char * code_type = "AP.code";
 
 GB_VERSION target_version;
 
+void
+mem_test(char * str)
+{
+int i;
+char ** d;
+#define SIZ	10000
+
+printf("mem %s\n",str);
+	d = malloc(SIZ*sizeof(char*));
+	for ( i = 0 ; i < SIZ ; i ++ )
+		d[i] = malloc(i+1);
+	for ( i = 0 ; i < SIZ ; i ++ )
+		free(d[i]);
+	free(d);
+}
+
+
 char *
 copy_str(char * str)
 {
@@ -207,7 +226,7 @@ STR_LIST * ret, ** sp, * n, * n2;
 	return ret;
 }
 
-STR_LIST *
+void
 divide_str_list(STR_LIST ** r1,STR_LIST ** r2,STR_LIST * in)
 {
 STR_LIST * ret1, * ret2, * n;
@@ -758,7 +777,7 @@ last:
 void
 mv_current(ARG_WORK * aw)
 {
-STR_LIST * sl, * top;
+STR_LIST * sl;
 char * arg;
 	arg = get_arg(aw);
 	if ( arg == 0 ) {
@@ -834,7 +853,7 @@ char * p;
 	len = 0;
 	for ( sl_1 = sl ; sl_1 ; sl_1 = sl_1->next )
 		len += strlen(sl_1->str) + 1;
-	last_message = malloc(len);
+	last_message = malloc(len+1);
 	p = last_message;
 	for ( sl_1 = sl ; sl_1 ; sl_1 = sl_1->next ) {
 		strcpy(p,sl_1->str);
@@ -1016,9 +1035,13 @@ int flags;
 				continue;
 			flags = 0;
 			for ( lg = log_list ; lg ; lg = lg->next )
-				if ( cmp_version(&lg->v,
-					&current_version) == 0 )
+				if ( cmp_version(&lg->v,&v) == 0 )
 					break;
+			if ( lg == 0 )
+				for ( lg = log_list ; lg ; lg = lg->next )
+					if ( cmp_version(&lg->v,
+						&current_version) == 0 )
+						break;
 		}
 		else {
 			convert_ver(&v,sl->str);
